@@ -2,7 +2,7 @@
  * @file gnome-cmd-dialog.cc
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2016 Uwe Scholz\n
+ * @copyright (C) 2013-2017 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -128,7 +128,7 @@ GtkType gnome_cmd_dialog_get_type ()
     {
         GtkTypeInfo dlg_info =
         {
-            "GnomeCmdDialog",
+            (gchar*) "GnomeCmdDialog",
             sizeof (GnomeCmdDialog),
             sizeof (GnomeCmdDialogClass),
             (GtkClassInitFunc) class_init,
