@@ -2,7 +2,7 @@
  * @file gnome-cmd-plugin.cc
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2016 Uwe Scholz\n
+ * @copyright (C) 2013-2017 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -77,9 +77,9 @@ GtkType gnome_cmd_plugin_get_type ()
 
     if (type == 0)
     {
-        GtkTypeInfo info =
+        static const GtkTypeInfo info =
         {
-            "GnomeCmdPlugin",
+            (char*) "GnomeCmdPlugin",
             sizeof (GnomeCmdPlugin),
             sizeof (GnomeCmdPluginClass),
             (GtkClassInitFunc) class_init,
