@@ -2,7 +2,7 @@
  * @file libgcmd-deps.h
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2016 Uwe Scholz\n
+ * @copyright (C) 2013-2017 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,8 +19,7 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-#ifndef __LIBGCMD_DEPS_H__
-#define __LIBGCMD_DEPS_H__
+#pragma once
 
 #include <glib.h>
 #include <glib/gi18n.h>
@@ -36,5 +35,3 @@
 #include <libgnomevfs/gnome-vfs-mime-handlers.h>
 
 extern GtkWidget *main_win_widget;
-
-#endif //__LIBGCMD_DEPS_H__
