@@ -2,7 +2,7 @@
  * @file libgcmd-widget-factory.cc
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2016 Uwe Scholz\n
+ * @copyright (C) 2013-2017 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -169,16 +169,6 @@ GtkWidget *create_hsep (GtkWidget *parent)
 }
 
 
-GtkWidget *create_vsep (GtkWidget *parent)
-{
-    GtkWidget *sep = gtk_vseparator_new ();
-    g_object_ref (sep);
-    g_object_set_data_full (G_OBJECT (parent), "sep", sep, g_object_unref);
-    gtk_widget_show (sep);
-    return sep;
-}
-
-
 GtkWidget *create_space_hbox (GtkWidget *parent, GtkWidget *content)
 {
     GtkWidget *hbox = create_hbox (parent, FALSE, 0);
@@ -285,7 +275,7 @@ GtkWidget *create_radio (GtkWidget *parent, GSList *group, const gchar *text, co
 }
 
 
-GtkWidget *create_radio_with_mnemonic (GtkWidget *parent, GSList *group, gchar *text, gchar *name)
+GtkWidget *create_radio_with_mnemonic (GtkWidget *parent, GSList *group, gchar *text, const gchar *name)
 {
     GtkWidget *radio = gtk_radio_button_new_with_mnemonic (group, text);
 
@@ -475,16 +465,6 @@ GtkWidget *create_progress_bar (GtkWidget *parent)
 }
 
 
-GtkWidget *create_pixmap (GtkWidget *parent, GdkPixmap *pm, GdkBitmap *mask)
-{
-    GtkWidget *w = gtk_pixmap_new (pm, mask);
-    g_object_ref (w);
-    g_object_set_data_full (G_OBJECT (parent), "pixmap", w, g_object_unref);
-    gtk_widget_show (w);
-    return w;
-}
-
-
 GtkWidget *create_sw (GtkWidget *parent)
 {
     GtkWidget *scrolledwindow = gtk_scrolled_window_new (NULL, NULL);
@@ -521,7 +501,6 @@ static void on_response (GtkDialog *dialog, gint id, gpointer data)
     gtk_widget_destroy (GTK_WIDGET (dialog));
 }
 
-
 void create_error_dialog (const gchar *msg, ...)
 {
     va_list      argptr;
