@@ -2,7 +2,7 @@
  * @file plugin-info.h
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2016 Uwe Scholz\n
+ * @copyright (C) 2013-2017 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,8 +19,7 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-#ifndef __PLUGIN_INFO_H__
-#define __PLUGIN_INFO_H__
+#pragma once
 
 /* This one should be increased when an api-incompatible change
  * is done to the plugin system. By doing that gcmd can detect
@@ -51,5 +50,3 @@ struct PluginInfo
  * since it is needed to determinate the version of a plugin
  */
 typedef PluginInfo *(*PluginInfoFunc)(void);
-
-#endif //__PLUGIN_INFO_H__
