@@ -2,7 +2,7 @@
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
     Copyright (C) 2007-2012 Piotr Eljasiak
-    Copyright (C) 2013-2016 Uwe Scholz
+    Copyright (C) 2013-2017 Uwe Scholz
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -19,18 +19,19 @@
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 
+#include <config.h>
 #include <stdlib.h>
+#include <string>
 #include <libgcmd/libgcmd.h>
 #include "file-roller-plugin.h"
 #include "file-roller.xpm"
 #include "file-roller-small.xpm"
 
 #define NAME "File Roller Plugin"
-#define COPYRIGHT "Copyright \n\xc2\xa9 2003-2006 Marcus Bjurman\n\xc2\xa9 2013-2016 Uwe Scholz"
+#define COPYRIGHT "Copyright \n\xc2\xa9 2003-2006 Marcus Bjurman\n\xc2\xa9 2013-2017 Uwe Scholz"
 #define AUTHOR "Marcus Bjurman <marbj499@student.liu.se>"
 #define TRANSLATOR_CREDITS "Translations: https://l10n.gnome.org/module/gnome-commander/"
 #define WEBPAGE "http://gcmd.github.io"
-#define VERSION "1.6.0"
 
 #define GCMD_PLUGINS_FILE_ROLLER                     "org.gnome.gnome-commander.plugins.file-roller-plugin"
 #define GCMD_PLUGINS_FILE_ROLLER_DEFAULT_TYPE        "default-type"
@@ -85,6 +86,34 @@ static const gchar *handled_extensions[NUMBER_OF_EXTENSIONS + 1] =
  * Functions for using GSettings
  ***********************************/
 
+static GSettingsSchemaSource* GetGlobalSchemaSource()
+{
+    GSettingsSchemaSource   *global_schema_source;
+    std::string              g_schema_path(PREFIX);
+
+    g_schema_path.append("/share/glib-2.0/schemas");
+
+    global_schema_source = g_settings_schema_source_get_default ();
+
+    GSettingsSchemaSource *parent = global_schema_source;
+    GError *error = NULL;
+
+    global_schema_source = g_settings_schema_source_new_from_directory
+                               ((gchar*) g_schema_path.c_str(),
+                                parent,
+                                FALSE,
+                                &error);
+
+    if (global_schema_source == NULL)
+    {
+        g_printerr(_("Could not load schemas from %s: %s\n"),
+                   (gchar*) g_schema_path.c_str(), error->message);
+        g_clear_error (&error);
+    }
+
+    return global_schema_source;
+}
+
 struct _PluginSettings
 {
     GObject parent;
@@ -122,7 +151,12 @@ PluginSettings *plugin_settings_new ()
 
 static void plugin_settings_init (PluginSettings *gs)
 {
-    gs->file_roller_plugin = g_settings_new (GCMD_PLUGINS_FILE_ROLLER);
+    GSettingsSchemaSource   *global_schema_source;
+    GSettingsSchema         *global_schema;
+
+    global_schema_source = GetGlobalSchemaSource();
+    global_schema = g_settings_schema_source_lookup (global_schema_source, GCMD_PLUGINS_FILE_ROLLER, FALSE);
+    gs->file_roller_plugin = g_settings_new_full (global_schema, NULL, NULL);
 }
 
 
@@ -201,15 +235,15 @@ inline void do_add_to_archive (const gchar *name, GnomeCmdState *state)
     for (files = state->active_dir_selected_files; files; files = files->next)
     {
         GnomeVFSURI *uri = GNOME_CMD_FILE_INFO (files->data)->uri;
-        gchar *uri_str = gnome_vfs_uri_to_string (uri, GNOME_VFS_URI_HIDE_PASSWORD);
-        gchar *path = gnome_vfs_get_local_path_from_uri (uri_str);
+        gchar *uri_str_file = gnome_vfs_uri_to_string (uri, GNOME_VFS_URI_HIDE_PASSWORD);
+        gchar *path = gnome_vfs_get_local_path_from_uri (uri_str_file);
         gchar *tmp = cmd;
-        gchar *arg = g_shell_quote (path);
-        cmd = g_strdup_printf ("%s %s", tmp, arg);
-        g_free (arg);
+        gchar *arg_file = g_shell_quote (path);
+        cmd = g_strdup_printf ("%s %s", tmp, arg_file);
+        g_free (arg_file);
         g_free (path);
         g_free (tmp);
-        g_free (uri_str);
+        g_free (uri_str_file);
     }
 
     g_printerr ("add: %s\n", cmd);
@@ -228,6 +262,7 @@ inline void do_add_to_archive (const gchar *name, GnomeCmdState *state)
 static gchar* new_string_with_replaced_keyword(const char* string, const char* keyword, const char* replacement)
 {
     gchar* new_string = NULL;
+    gchar* longer_string = NULL;
     gchar* replacement_tmp;
 
     if (keyword == NULL || strlen(keyword) == 0)
@@ -249,7 +284,17 @@ static gchar* new_string_with_replaced_keyword(const char* string, const char* k
         while (in_filename != temp_ptr)
         {
             if (new_string)
-                new_string = (char*) realloc(new_string, strlen(new_string) + 1);
+            {
+                longer_string = (char*) realloc(new_string, strlen(new_string) + 1);
+                if (longer_string)
+                    new_string = longer_string;
+                else
+                {
+                    g_warning("Error (re)allocating memory!");
+                    g_free(replacement_tmp);
+                    return (char*) string;
+                }
+            }
             else
                 new_string = (char*) calloc(1, 2);
             new_string[i] = *(in_filename++);
@@ -257,9 +302,21 @@ static gchar* new_string_with_replaced_keyword(const char* string, const char* k
         }
 
         if (new_string)
-            new_string = (char*) realloc(new_string, strlen(new_string) + strlen(replacement_tmp) + 1);
+        {
+            longer_string = (char*) realloc(new_string, strlen(new_string) + strlen(replacement_tmp) + 1);
+            if (longer_string)
+                new_string = longer_string;
+            else
+            {
+                g_warning("Error (re)allocating memory!");
+                g_free(replacement_tmp);
+                return (char*) string;
+            }
+        }
         else
+        {
             new_string = (char*) calloc(1, strlen(replacement_tmp) + 1);
+        }
 
         strcat(new_string, replacement_tmp);
         i += strlen(replacement_tmp);
@@ -287,10 +344,6 @@ static void on_add_to_archive (GtkMenuItem *item, FileRollerPlugin *plugin)
 {
     gint ret;
     GtkWidget *dialog = NULL;
-    GdkPixbuf *pixbuf;
-    GtkWidget *entry;
-    GtkWidget *hbox;
-    gchar *archive_name;
     const gchar *name;
     gboolean name_ok = FALSE;
     GList *files;
@@ -299,6 +352,11 @@ static void on_add_to_archive (GtkMenuItem *item, FileRollerPlugin *plugin)
 
     do
     {
+        GdkPixbuf *pixbuf;
+        GtkWidget *entry;
+        GtkWidget *hbox;
+        gchar *archive_name;
+
         if (dialog)
             gtk_widget_destroy (dialog);
 
@@ -325,7 +383,14 @@ static void on_add_to_archive (GtkMenuItem *item, FileRollerPlugin *plugin)
         char s[256];
         time_t t = time (NULL);
 
+#if defined (__GNUC__)
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wformat-nonliteral"
+#endif
         strftime (s, sizeof(s), locale_format, localtime (&t));
+#if defined (__GNUC__)
+#pragma GCC diagnostic pop
+#endif
         g_free (locale_format);
         gchar *file_prefix = g_locale_to_utf8 (s, -1, NULL, NULL, NULL);
 
@@ -417,7 +482,7 @@ static GList *create_popup_menu_items (GnomeCmdPlugin *plugin, GnomeCmdState *st
 
     FILE_ROLLER_PLUGIN (plugin)->priv->state = state;
 
-    item = create_menu_item (_("Create Archive..."), TRUE, GTK_SIGNAL_FUNC (on_add_to_archive), plugin);
+    item = create_menu_item (_("Create Archive…"), TRUE, GTK_SIGNAL_FUNC (on_add_to_archive), plugin);
     items = g_list_append (items, item);
 
     if (num_files == 1)
@@ -436,7 +501,7 @@ static GList *create_popup_menu_items (GnomeCmdPlugin *plugin, GnomeCmdState *st
 
                 gchar *text;
 
-                text = g_strdup_printf (_("Extract to '%s'"), fname);
+                text = g_strdup_printf (_("Extract to “%s”"), fname);
                 item = create_menu_item (text, TRUE, GTK_SIGNAL_FUNC (on_extract_cwd), f->uri);
                 g_object_set_data (G_OBJECT (item), "target_name", g_strdup (fname));
                 items = g_list_append (items, item);
@@ -446,7 +511,7 @@ static GList *create_popup_menu_items (GnomeCmdPlugin *plugin, GnomeCmdState *st
                 {
                     gchar *path = gnome_vfs_unescape_string (gnome_vfs_uri_get_path (state->inactive_dir_uri), NULL);
 
-                    text = g_strdup_printf (_("Extract to '%s'"), path);
+                    text = g_strdup_printf (_("Extract to “%s”"), path);
                     item = create_menu_item (text, TRUE, GTK_SIGNAL_FUNC (on_extract_cwd), f->uri);
                     g_object_set_data (G_OBJECT (item), "target_dir", path);
                     items = g_list_append (items, item);
@@ -493,7 +558,14 @@ static void on_date_format_update (GtkEditable *editable, GtkWidget *options_dia
     char s[256];
     time_t t = time (NULL);
 
+#if defined (__GNUC__)
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wformat-nonliteral"
+#endif
     strftime (s, sizeof(s), locale_format, localtime (&t));
+#if defined (__GNUC__)
+#pragma GCC diagnostic pop
+#endif
     gchar *file_prefix = g_locale_to_utf8 (s, -1, NULL, NULL, NULL);
     gchar *filename_tmp = g_strdup_printf("%s%s", file_prefix, file_suffix);
     gchar *replacement = g_strdup(_("File"));
@@ -554,7 +626,7 @@ static void configure (GnomeCmdPlugin *plugin)
     g_object_set_data (G_OBJECT (dialog), "date_format_test_label", label);
     table_add (table, label, 1, 3, (GtkAttachOptions) (GTK_EXPAND|GTK_FILL));
 
-    gchar* text = g_strdup_printf("<small>%s</small>",_("Use $N as a pattern for the original file name. See the manual page for \"strftime\" for other patterns."));
+    gchar* text = g_strdup_printf("<small>%s</small>",_("Use $N as a pattern for the original file name. See the manual page for “strftime” for other patterns."));
     label = create_label (dialog, text);
     gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
     gtk_label_set_markup (GTK_LABEL (label), text);
@@ -692,21 +764,27 @@ GnomeCmdPlugin *file_roller_plugin_new ()
 }
 
 
-extern "C" GnomeCmdPlugin *create_plugin ()
+extern "C"
 {
-    return file_roller_plugin_new ();
-}
-
-
-extern "C" PluginInfo *get_plugin_info ()
-{
-    if (!plugin_nfo.authors)
+    GnomeCmdPlugin *create_plugin ()
     {
-        plugin_nfo.authors = g_new0 (gchar *, 2);
-        plugin_nfo.authors[0] = (char*) AUTHOR;
-        plugin_nfo.authors[1] = NULL;
-        plugin_nfo.comments = g_strdup (_("A plugin that adds File Roller shortcuts for creating "
-                                          "and extracting compressed archives."));
+        return file_roller_plugin_new ();
+    }
+}
+
+
+extern "C"
+{
+    PluginInfo *get_plugin_info ()
+    {
+        if (!plugin_nfo.authors)
+        {
+            plugin_nfo.authors = g_new0 (gchar *, 2);
+            plugin_nfo.authors[0] = (gchar*) AUTHOR;
+            plugin_nfo.authors[1] = NULL;
+            plugin_nfo.comments = g_strdup (_("A plugin that adds File Roller shortcuts for creating "
+                                            "and extracting compressed archives."));
+        }
+        return &plugin_nfo;
     }
-    return &plugin_nfo;
 }
