@@ -2,7 +2,7 @@
  * @file gnome-cmd-advrename-dialog.cc
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2016 Uwe Scholz\n
+ * @copyright (C) 2013-2017 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,7 +24,7 @@
 #include <regex.h>
 #include <unistd.h>
 #include <errno.h>
-#include <gtk/gtkdialog.h>
+#include <gtk/gtk.h>
 
 #include "gnome-cmd-includes.h"
 #include "gnome-cmd-advrename-dialog.h"
@@ -94,6 +94,9 @@ inline GnomeCmdAdvrenameDialog::Private::Private()
 {
     profile_menu_button = NULL;
     template_has_counters = FALSE;
+    vbox = NULL;
+    profile_component = NULL;
+    files_view = NULL;
 }
 
 
@@ -120,27 +123,28 @@ inline GtkWidget *GnomeCmdAdvrenameDialog::Private::create_placeholder_menu(Gnom
 {
     guint items_size = cfg->profiles.empty() ? 1 : cfg->profiles.size()+3;
     GtkItemFactoryEntry *items = g_try_new0 (GtkItemFactoryEntry, items_size);
-    GtkItemFactoryEntry *i = items;
 
     g_return_val_if_fail (items!=NULL, NULL);
 
-    i->path = g_strdup (_("/_Save Profile As..."));
+    GtkItemFactoryEntry *i = items;
+
+    i->path = g_strdup (_("/_Save Profile As…"));
     i->callback = (GtkItemFactoryCallback) manage_profiles;
     i->callback_action = TRUE;
-    i->item_type = "<StockItem>";
+    i->item_type = (gchar *) "<StockItem>";
     i->extra_data = GTK_STOCK_SAVE_AS;
     ++i;
 
     if (!cfg->profiles.empty())
     {
-        i->path = g_strdup (_("/_Manage Profiles..."));
+        i->path = g_strdup (_("/_Manage Profiles…"));
         i->callback = (GtkItemFactoryCallback) manage_profiles;
-        i->item_type = "<StockItem>";
+        i->item_type = (gchar *) "<StockItem>";
         i->extra_data = GTK_STOCK_EDIT;
         ++i;
 
         i->path = g_strdup ("/");
-        i->item_type = "<Separator>";
+        i->item_type = (gchar *) "<Separator>";
         ++i;
 
         for (vector<GnomeCmdData::AdvrenameConfig::Profile>::const_iterator p=cfg->profiles.begin(); p!=cfg->profiles.end(); ++p, ++i)
@@ -148,7 +152,7 @@ inline GtkWidget *GnomeCmdAdvrenameDialog::Private::create_placeholder_menu(Gnom
             i->path = g_strconcat ("/", p->name.c_str(), NULL);
             i->callback = (GtkItemFactoryCallback) load_profile;
             i->callback_action = (i-items)-3;
-            i->item_type = "<StockItem>";
+            i->item_type = (gchar *) "<StockItem>";
             i->extra_data = GTK_STOCK_REVERT_TO_SAVED;
         }
     }
@@ -157,8 +161,8 @@ inline GtkWidget *GnomeCmdAdvrenameDialog::Private::create_placeholder_menu(Gnom
 
     gtk_item_factory_create_items (ifac, items_size, items, this);
 
-    for (guint i=0; i<items_size; ++i)
-        g_free (items[i].path);
+    for (guint ii=0; ii<items_size; ++ii)
+        g_free (items[ii].path);
 
     g_free (items);
 
@@ -694,7 +698,7 @@ GnomeCmdAdvrenameDialog::GnomeCmdAdvrenameDialog(GnomeCmdData::AdvrenameConfig &
     gtk_window_set_transient_for (*this, *main_win);
 
     gtk_dialog_add_action_widget (*this,
-                                  priv->create_button_with_menu (_("Profiles..."), &cfg),
+                                  priv->create_button_with_menu (_("Profiles…"), &cfg),
                                   GCMD_RESPONSE_PROFILES);
 
     gtk_dialog_add_buttons (*this,
