@@ -2,7 +2,7 @@
  * @file gnome-cmd-advrename-regex-dialog.h
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2016 Uwe Scholz\n
+ * @copyright (C) 2013-2017 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,12 +19,9 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-#ifndef __GNOME_CMD_ADVRENAME_REGEX_DIALOG_H__
-#define __GNOME_CMD_ADVRENAME_REGEX_DIALOG_H__
+#pragma once
 
 #include "gnome-cmd-advrename-dialog.h"
 #include "gnome-cmd-regex.h"
 
 gboolean gnome_cmd_advrename_regex_dialog_new (const gchar *title, GtkWindow *parent, GnomeCmd::RegexReplace *rx);
-
-#endif // __GNOME_CMD_ADVRENAME_REGEX_DIALOG_H__
