@@ -2,7 +2,7 @@
  * @file gnome-cmd-chmod-dialog.cc
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2016 Uwe Scholz\n
+ * @copyright (C) 2013-2017 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -41,7 +41,7 @@ enum ChmodRecursiveMode
     CHMOD_MAX
 };
 
-static gchar *recurse_opts[CHMOD_MAX] = {
+static const gchar *recurse_opts[CHMOD_MAX] = {
     N_("All files"),
     N_("Directories only")
 };
