@@ -2,7 +2,7 @@
  * @file gnome-cmd-delete-dialog.cc
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2016 Uwe Scholz\n
+ * @copyright (C) 2013-2017 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -48,7 +48,7 @@ struct DeleteData
     gboolean delete_done;         // tells the main thread that the work thread is done
     gchar *msg;                   // a message descriping the current status of the delete operation
     gfloat progress;              // a float values between 0 and 1 representing the progress of the whole operation
-    GMutex *mutex;                // used to sync the main and worker thread
+    GMutex mutex;                 // used to sync the main and worker thread
 };
 
 
@@ -63,7 +63,7 @@ static gint delete_progress_callback (GnomeVFSXferProgressInfo *info, DeleteData
 {
     gint ret = 0;
 
-    g_mutex_lock (data->mutex);
+    g_mutex_lock (&data->mutex);
 
     if (info->status == GNOME_VFS_XFER_PROGRESS_STATUS_VFSERROR)
     {
@@ -71,10 +71,10 @@ static gint delete_progress_callback (GnomeVFSXferProgressInfo *info, DeleteData
         data->problem_file = str_uri_basename(info->source_name);
         data->problem = TRUE;
 
-        g_mutex_unlock (data->mutex);
+        g_mutex_unlock (&data->mutex);
         while (data->problem_action == -1)
             g_thread_yield ();
-        g_mutex_lock (data->mutex);
+        g_mutex_lock (&data->mutex);
         ret = data->problem_action;
         data->problem_action = -1;
         g_free (data->problem_file);
@@ -84,7 +84,7 @@ static gint delete_progress_callback (GnomeVFSXferProgressInfo *info, DeleteData
     else
         if (info->status == GNOME_VFS_XFER_PROGRESS_STATUS_OK)
         {
-            if (info->file_index >= 0 && info->files_total > 0)
+            if (info->files_total > 0)
             {
                 gfloat f = (gfloat)info->file_index/(gfloat)info->files_total;
                 g_free (data->msg);
@@ -102,7 +102,7 @@ static gint delete_progress_callback (GnomeVFSXferProgressInfo *info, DeleteData
         else
             data->vfs_status = info->vfs_status;
 
-    g_mutex_unlock (data->mutex);
+    g_mutex_unlock (&data->mutex);
 
     return ret;
 }
@@ -130,7 +130,7 @@ inline void create_delete_progress_win (DeleteData *data)
     GtkWidget *button;
 
     data->progwin = gtk_window_new (GTK_WINDOW_TOPLEVEL);
-    gtk_window_set_title (GTK_WINDOW (data->progwin), _("Deleting..."));
+    gtk_window_set_title (GTK_WINDOW (data->progwin), _("Deleting…"));
     gtk_window_set_policy (GTK_WINDOW (data->progwin), FALSE, FALSE, FALSE);
     gtk_window_set_position (GTK_WINDOW (data->progwin), GTK_WIN_POS_CENTER);
     gtk_widget_set_size_request (GTK_WIDGET (data->progwin), 300, -1);
@@ -194,7 +194,7 @@ static void perform_delete_operation (DeleteData *data)
 
 static gboolean update_delete_status_widgets (DeleteData *data)
 {
-    g_mutex_lock (data->mutex);
+    g_mutex_lock (&data->mutex);
 
     gtk_label_set_text (GTK_LABEL (data->proglabel), data->msg);
     gtk_progress_set_percentage (GTK_PROGRESS (data->progbar), data->progress);
@@ -202,7 +202,7 @@ static gboolean update_delete_status_widgets (DeleteData *data)
     if (data->problem)
     {
         const gchar *error = gnome_vfs_result_to_string (data->vfs_status);
-        gchar *msg = g_strdup_printf (_("Error while deleting \"%s\"\n\n%s"), data->problem_file, error);
+        gchar *msg = g_strdup_printf (_("Error while deleting “%s”\n\n%s"), data->problem_file, error);
 
         data->problem_action = run_simple_dialog (
             *main_win, TRUE, GTK_MESSAGE_ERROR, msg, _("Delete problem"),
@@ -212,7 +212,7 @@ static gboolean update_delete_status_widgets (DeleteData *data)
         data->problem = FALSE;
     }
 
-    g_mutex_unlock (data->mutex);
+    g_mutex_unlock (&data->mutex);
 
 
     if (data->delete_done)
@@ -243,14 +243,15 @@ static gboolean update_delete_status_widgets (DeleteData *data)
 
 inline void do_delete (DeleteData *data)
 {
-    data->mutex = g_mutex_new ();
+    g_mutex_init(&data->mutex);
     data->delete_done = FALSE;
     data->vfs_status = GNOME_VFS_OK;
     data->problem_action = -1;
     create_delete_progress_win (data);
 
-    data->thread = g_thread_create ((GThreadFunc) perform_delete_operation, data, FALSE, NULL);
+    data->thread = g_thread_new (NULL, (GThreadFunc) perform_delete_operation, data);
     g_timeout_add (gnome_cmd_data.gui_update_rate, (GSourceFunc) update_delete_status_widgets, data);
+    g_mutex_clear(&data->mutex);
 }
 
 
@@ -274,7 +275,7 @@ void gnome_cmd_delete_dialog_show (GList *files)
                 return;
 
             gchar *fname = get_utf8 (f->info->name);
-            msg = g_strdup_printf (_("Do you want to delete \"%s\"?"), fname);
+            msg = g_strdup_printf (_("Do you want to delete “%s”?"), fname);
             g_free (fname);
         }
         else
