@@ -19,11 +19,8 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-#ifndef __GNOME_CMD_FILE_PROPS_DIALOG_H__
-#define __GNOME_CMD_FILE_PROPS_DIALOG_H__
+#pragma once
 
 #include "gnome-cmd-file.h"
 
 GtkWidget *gnome_cmd_file_props_dialog_create (GnomeCmdFile *f);
-
-#endif // __GNOME_CMD_FILE_PROPS_DIALOG_H__
