@@ -2,7 +2,7 @@
  * @file gnome-cmd-key-shortcuts-dialog.cc
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2016 Uwe Scholz\n
+ * @copyright (C) 2013-2017 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -69,8 +69,14 @@ inline GnomeCmdKeyShortcutsDialogPrivate::GnomeCmdKeyShortcutsDialogPrivate()
 GnomeCmdUserActions *GnomeCmdKeyShortcutsDialog::user_actions = NULL;
 
 
+#if defined (__GNUC__)
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wmissing-declarations"
+#endif
 G_DEFINE_TYPE (GnomeCmdKeyShortcutsDialog, gnome_cmd_key_shortcuts_dialog, GTK_TYPE_DIALOG)
-
+#if defined (__GNUC__)
+#pragma GCC diagnostic pop
+#endif
 
 static void gnome_cmd_key_shortcuts_dialog_finalize (GObject *object)
 {
@@ -483,7 +489,7 @@ inline gboolean conflict_confirm (GtkWidget *view, const gchar *action, guint ac
                                              (GtkDialogFlags) (GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT),
                                              GTK_MESSAGE_WARNING,
                                              GTK_BUTTONS_NONE,
-                                             _("Shortcut \"%s\" is already taken by \"%s\"."),
+                                             _("Shortcut “%s” is already taken by “%s”."),
                                              accel_string, action);
     gtk_dialog_add_buttons (GTK_DIALOG (dlg), GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
                                               _("_Reassign shortcut"), GTK_RESPONSE_OK,
@@ -491,7 +497,7 @@ inline gboolean conflict_confirm (GtkWidget *view, const gchar *action, guint ac
     gtk_dialog_set_default_response (GTK_DIALOG (dlg), GTK_RESPONSE_CANCEL);
     gtk_window_set_title (GTK_WINDOW (dlg), _("Conflicting Shortcuts"));
     gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dlg), _("Reassigning the shortcut will cause it "
-                                                                          "to be removed from \"%s\"."), action);
+                                                                          "to be removed from “%s”."), action);
     gtk_widget_show_all (dlg);
     gint response = gtk_dialog_run (GTK_DIALOG (dlg));
 
@@ -588,6 +594,7 @@ static void cell_edited_callback (GtkCellRendererText *cell, gchar *path_string,
     gint col = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (cell), "column"));
 
     if (gtk_tree_model_get_iter (model, &iter, path))
+    {
         if (col==COL_ACTION && GnomeCmdKeyShortcutsDialog::user_actions)
             gtk_list_store_set (GTK_LIST_STORE (model), &iter,
                                 col, new_text,
@@ -597,6 +604,7 @@ static void cell_edited_callback (GtkCellRendererText *cell, gchar *path_string,
             gtk_list_store_set (GTK_LIST_STORE (model), &iter,
                                 col, new_text,
                                 -1);
+    }
 
     gtk_tree_path_free (path);
 }
