@@ -2,7 +2,7 @@
  * @file gnome-cmd-make-copy-dialog.cc
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2016 Uwe Scholz\n
+ * @copyright (C) 2013-2017 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -33,7 +33,6 @@ struct GnomeCmdMakeCopyDialogPrivate
 {
     GnomeCmdFile *f;
     GnomeCmdDir *dir;
-    GnomeCmdMainWin *mw;
 };
 
 
@@ -135,7 +134,7 @@ GtkWidget *gnome_cmd_make_copy_dialog_new (GnomeCmdFile *f, GnomeCmdDir *dir)
     dialog->priv->f = f->ref();
     dialog->priv->dir = gnome_cmd_dir_ref (dir);
 
-    gchar *msg = g_strdup_printf (_("Copy \"%s\" to"), f->get_name());
+    gchar *msg = g_strdup_printf (_("Copy “%s” to"), f->get_name());
     GtkWidget *msg_label = create_label (GTK_WIDGET (dialog), msg);
     g_free (msg);
 
@@ -163,7 +162,7 @@ GtkType gnome_cmd_make_copy_dialog_get_type ()
     {
         GtkTypeInfo dlg_info =
         {
-            "GnomeCmdMakeCopyDialog",
+            (gchar*) "GnomeCmdMakeCopyDialog",
             sizeof (GnomeCmdMakeCopyDialog),
             sizeof (GnomeCmdMakeCopyDialogClass),
             (GtkClassInitFunc) class_init,
