@@ -2,7 +2,7 @@
  * @file gnome-cmd-make-copy-dialog.h
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2016 Uwe Scholz\n
+ * @copyright (C) 2013-2017 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,8 +19,7 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-#ifndef __GNOME_CMD_MAKE_COPY_DIALOG_H__
-#define __GNOME_CMD_MAKE_COPY_DIALOG_H__
+#pragma once
 
 #include "gnome-cmd-file.h"
 
@@ -51,5 +50,3 @@ struct GnomeCmdMakeCopyDialogClass
 GtkWidget *gnome_cmd_make_copy_dialog_new (GnomeCmdFile *f, GnomeCmdDir *dir);
 
 GtkType gnome_cmd_make_copy_dialog_get_type ();
-
-#endif // __GNOME_CMD_MAKE_COPY_DIALOG_H__
