@@ -2,7 +2,7 @@
  * @file gnome-cmd-options-dialog.h
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2016 Uwe Scholz\n
+ * @copyright (C) 2013-2017 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,11 +18,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  */
-#ifndef __GNOME_CMD_OPTIONS_DIALOG_H__
-#define __GNOME_CMD_OPTIONS_DIALOG_H__
+#pragma once
 
 #include "gnome-cmd-data.h"
 
 gboolean gnome_cmd_options_dialog (GtkWindow *parent, GnomeCmdData::Options &cfg);
-
-#endif // __GNOME_CMD_OPTIONS_DIALOG_H__
