@@ -2,7 +2,7 @@
  * @file gnome-cmd-prepare-move-dialog.cc
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2016 Uwe Scholz\n
+ * @copyright (C) 2013-2017 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -123,7 +123,7 @@ void gnome_cmd_prepare_move_dialog_show (GnomeCmdFileSelector *from, GnomeCmdFil
     {
         GnomeCmdFile *f = (GnomeCmdFile *) data->dialog->src_files->data;
         gchar *fname = get_utf8 (f->info->name);
-        dest_dir_frame_msg = g_strdup_printf (_("Move \"%s\" to"), fname);
+        dest_dir_frame_msg = g_strdup_printf (_("Move “%s” to"), fname);
         g_free (fname);
     }
     else
