@@ -2,7 +2,7 @@
  * @file gnome-cmd-prepare-move-dialog.h
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2016 Uwe Scholz\n
+ * @copyright (C) 2013-2017 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,12 +18,9 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  */
-#ifndef __GNOME_CMD_PREPARE_MOVE_DIALOG_H__
-#define __GNOME_CMD_PREPARE_MOVE_DIALOG_H__
+#pragma once
 
 #include "gnome-cmd-file-list.h"
 #include "gnome-cmd-file-selector.h"
 
 void gnome_cmd_prepare_move_dialog_show (GnomeCmdFileSelector *from, GnomeCmdFileSelector *to);
-
-#endif // __GNOME_CMD_PREPARE_MOVE_DIALOG_H__
