@@ -2,7 +2,7 @@
  * @file eggcellrendererkeys.cc
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2016 Uwe Scholz\n
+ * @copyright (C) 2013-2017 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -242,19 +242,13 @@ gchar *egg_accelerator_get_label (guint accel_key, GdkModifierType accel_mods)
     static const gchar text_mod1[] = "Alt+";
     static const gchar text_mod2[] = "Mod2+";
     static const gchar text_mod3[] = "Mod3+";
-#if GTK_CHECK_VERSION (2, 10, 0)
     static const gchar text_mod4[] = "Mod4+";
-#else
-    static const gchar text_mod4[] = "Super+";
-#endif
     static const gchar text_mod5[] = "Mod5+";
-#if GTK_CHECK_VERSION (2, 10, 0)
     static const gchar text_meta[] = "Meta+";
     static const gchar text_super[] = "Super+";
     static const gchar text_hyper[] = "Hyper+";
-#endif
 
-    gchar *keyval_name = gdk_keyval_name (gdk_keyval_to_upper (accel_key));
+    const gchar *keyval_name = gdk_keyval_name (gdk_keyval_to_upper (accel_key));
     if (!keyval_name)
         keyval_name = "";
 
@@ -274,14 +268,12 @@ gchar *egg_accelerator_get_label (guint accel_key, GdkModifierType accel_mods)
         l += sizeof(text_mod4)-1;
     if (accel_mods & GDK_MOD5_MASK)
         l += sizeof(text_mod5)-1;
-#if GTK_CHECK_VERSION (2, 10, 0)
     if (accel_mods & GDK_META_MASK)
         l += sizeof(text_meta)-1;
     if (accel_mods & GDK_HYPER_MASK)
         l += sizeof(text_hyper)-1;
     if (accel_mods & GDK_SUPER_MASK)
         l += sizeof(text_super)-1;
-#endif
 
     gchar *accelerator = g_new (gchar, l+1);
     gchar *s = accelerator;
@@ -321,7 +313,6 @@ gchar *egg_accelerator_get_label (guint accel_key, GdkModifierType accel_mods)
       strcpy (s, text_mod5);
       s +=  sizeof(text_mod5)-1;
     }
-#if GTK_CHECK_VERSION (2, 10, 0)
     if (accel_mods & GDK_META_MASK)
     {
       strcpy (s, text_meta);
@@ -337,7 +328,6 @@ gchar *egg_accelerator_get_label (guint accel_key, GdkModifierType accel_mods)
       strcpy (s, text_super);
       s +=  sizeof(text_super)-1;
     }
-#endif
 
     strcpy (s, keyval_name);
 
@@ -432,7 +422,7 @@ void egg_cell_renderer_keys_get_size (GtkCellRenderer *cell,
     GtkRequisition requisition;
 
     if (keys->sizing_label == NULL)
-        keys->sizing_label = gtk_label_new (_("New accelerator..."));
+        keys->sizing_label = gtk_label_new (_("New accelerator…"));
 
     gtk_widget_size_request (keys->sizing_label, &requisition);
     GTK_CELL_RENDERER_CLASS (parent_class)->get_size (cell, widget, cell_area, x_offset, y_offset, width, height);
@@ -447,13 +437,8 @@ void egg_cell_renderer_keys_get_size (GtkCellRenderer *cell,
 
 static gboolean grab_key_callback (GtkWidget *widget, GdkEventKey *event, EggCellRendererKeys *keys)
 {
-#if GTK_CHECK_VERSION (2, 10, 0)
     if (event->is_modifier)
         return TRUE;
-#else
-    if (is_modifier (event->hardware_keycode))
-        return TRUE;
-#endif
 
     switch (event->keyval)
     {
@@ -464,6 +449,8 @@ static gboolean grab_key_callback (GtkWidget *widget, GdkEventKey *event, EggCel
         // case GDK_Hyper_L:
         // case GDK_Hyper_R:
             return TRUE;
+        default:
+            break;
     }
 
     GdkDisplay *display = gtk_widget_get_display (widget);
@@ -484,11 +471,7 @@ static gboolean grab_key_callback (GtkWidget *widget, GdkEventKey *event, EggCel
     if (accel_key == GDK_ISO_Left_Tab)
         accel_key = GDK_Tab;
 
-#if GTK_CHECK_VERSION (2, 10, 0)
     accel_mods = event->state & gtk_accelerator_get_default_mod_mask ();
-#else
-    accel_mods = event->state & (GDK_CONTROL_MASK | GDK_SHIFT_MASK | GDK_MOD1_MASK | GDK_MOD4_MASK);
-#endif
 
     // filter consumed modifiers
     if (keys->accel_mode == GTK_CELL_RENDERER_ACCEL_MODE_GTK)
@@ -515,9 +498,7 @@ static gboolean grab_key_callback (GtkWidget *widget, GdkEventKey *event, EggCel
     if (keys->accel_mode == GTK_CELL_RENDERER_ACCEL_MODE_GTK)
         if (accel_key != GDK_Tab && !gtk_accelerator_valid (accel_key, (GdkModifierType) accel_mods))
         {
-#if GTK_CHECK_VERSION (2, 12, 0)
             gtk_widget_error_bell (widget);
-#endif
             return TRUE;
         }
 
@@ -647,7 +628,7 @@ egg_cell_renderer_keys_start_editing (GtkCellRenderer      *cell,
 
     gtk_widget_modify_fg (label, GTK_STATE_NORMAL, &widget->style->fg[GTK_STATE_SELECTED]);
 
-    gtk_label_set_text (GTK_LABEL (label), _("New accelerator..."));
+    gtk_label_set_text (GTK_LABEL (label), _("New accelerator…"));
 
     gtk_container_add (GTK_CONTAINER (eventbox), label);
 
