@@ -2,7 +2,7 @@
  * @file gnome-cmd-advrename-profile-component.h
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2016 Uwe Scholz\n
+ * @copyright (C) 2013-2017 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,8 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  */
-#ifndef __GNOME_CMD_ADVRENAME_PROFILE_COMPONENT_H__
-#define __GNOME_CMD_ADVRENAME_PROFILE_COMPONENT_H__
+#pragma once
 
 #include "gnome-cmd-data.h"
 
@@ -51,7 +50,7 @@ struct GnomeCmdAdvrenameProfileComponent
 
     GnomeCmdData::AdvrenameConfig::Profile &profile;
 
-    GnomeCmdAdvrenameProfileComponent(GnomeCmdData::AdvrenameConfig::Profile &profile);
+    explicit GnomeCmdAdvrenameProfileComponent(GnomeCmdData::AdvrenameConfig::Profile &profile);
     ~GnomeCmdAdvrenameProfileComponent()     {}
 
     void update();
@@ -66,5 +65,3 @@ struct GnomeCmdAdvrenameProfileComponent
     void set_sample_fname(const gchar *fname);
     GtkTreeModel *get_regex_model() const;
 };
-
-#endif // __GNOME_CMD_ADVRENAME_PROFILE_COMPONENT_H__
