@@ -2,7 +2,7 @@
  * @file gnome-cmd-app.h
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2016 Uwe Scholz\n
+ * @copyright (C) 2013-2017 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,8 +19,7 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-#ifndef __GNOME_CMD_APP_H__
-#define __GNOME_CMD_APP_H__
+#pragma once
 
 #include "gnome-cmd-file.h"
 #include "gnome-cmd-pixmap.h"
@@ -94,5 +93,3 @@ gboolean gnome_cmd_app_get_requires_terminal (GnomeCmdApp *app);
 void gnome_cmd_app_set_requires_terminal (GnomeCmdApp *app, gboolean requires_terminal);
 
 GnomeCmdPixmap *gnome_cmd_app_get_pixmap (GnomeCmdApp *app);
-
-#endif // __GNOME_CMD_APP_H__
