@@ -2,7 +2,7 @@
  * @file gnome-cmd-chown-component.cc
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2016 Uwe Scholz\n
+ * @copyright (C) 2013-2017 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -135,7 +135,7 @@ GtkType gnome_cmd_chown_component_get_type ()
     {
         GtkTypeInfo info =
         {
-            "GnomeCmdChownComponent",
+            (gchar*) "GnomeCmdChownComponent",
             sizeof (GnomeCmdChownComponent),
             sizeof (GnomeCmdChownComponentClass),
             (GtkClassInitFunc) class_init,
