@@ -2,7 +2,7 @@
  * @file gnome-cmd-combo.cc
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2016 Uwe Scholz\n
+ * @copyright (C) 2013-2017 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -450,7 +450,7 @@ GtkType gnome_cmd_combo_get_type ()
     {
         static const GtkTypeInfo combo_info =
         {
-            "GnomeCmdCombo",
+            (gchar*) "GnomeCmdCombo",
             sizeof (GnomeCmdCombo),
             sizeof (GnomeCmdComboClass),
             (GtkClassInitFunc) class_init,
@@ -524,13 +524,6 @@ void GnomeCmdCombo::set_pixmap(gint row, gint col, GnomeCmdPixmap *pixmap)
 }
 
 
-void GnomeCmdCombo::select_text(const gchar *text)
-{
-    if (text)
-        gtk_entry_set_text (GTK_ENTRY (entry), text);
-}
-
-
 void GnomeCmdCombo::select_data(gpointer data)
 {
     GtkCList *clist = GTK_CLIST (list);
