@@ -2,7 +2,7 @@
  * @file gnome-cmd-convert.h
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2016 Uwe Scholz\n
+ * @copyright (C) 2013-2017 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,8 +19,7 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-#ifndef __GNOME_CMD_CONVERT_H__
-#define __GNOME_CMD_CONVERT_H__
+#pragma once
 
 typedef gchar *(*GnomeCmdConvertFunc) (gchar *string);
 
@@ -35,5 +34,3 @@ gchar *gcmd_convert_uppercase (gchar *string);
 gchar *gcmd_convert_sentence_case (gchar *string);
 gchar *gcmd_convert_initial_caps (gchar *string);
 gchar *gcmd_convert_toggle_case (gchar *string);
-
-#endif // __GNOME_CMD_CONVERT_H__
