@@ -2,7 +2,7 @@
  * @file gnome-cmd-data.h
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2016 Uwe Scholz\n
+ * @copyright (C) 2013-2017 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,8 +19,7 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-#ifndef __GNOME_CMD_DATA_H__
-#define __GNOME_CMD_DATA_H__
+#pragma once
 
 #include <vector>
 #include <string>
@@ -87,6 +86,8 @@ GcmdSettings *gcmd_settings_new (void);
 #define GCMD_SETTINGS_SAVE_DIRS_ON_EXIT               "save-dirs-on-exit"
 #define GCMD_SETTINGS_SAVE_TABS_ON_EXIT               "save-tabs-on-exit"
 #define GCMD_SETTINGS_SAVE_DIR_HISTORY_ON_EXIT        "save-dir-history-on-exit"
+#define GCMD_SETTINGS_SAVE_CMDLINE_HISTORY_ON_EXIT    "save-cmdline-history-on-exit"
+#define GCMD_SETTINGS_SAVE_SEARCH_HISTORY_ON_EXIT     "save-search-history-on-exit"
 #define GCMD_SETTINGS_ALWAYS_SHOW_TABS                "always-show-tabs"
 #define GCMD_SETTINGS_TAB_LOCK_INDICATOR              "tab-lock-indicator"
 #define GCMD_SETTINGS_MAIN_WIN_STATE                  "main-win-state"
@@ -262,6 +263,8 @@ struct GnomeCmdData
         gboolean                     save_dirs_on_exit;
         gboolean                     save_tabs_on_exit;
         gboolean                     save_dir_history_on_exit;
+        gboolean                     save_cmdline_history_on_exit;
+        gboolean                     save_search_history_on_exit;
         gchar                       *symlink_prefix;
         gint                         main_win_pos[2];
         // Format
@@ -320,6 +323,8 @@ struct GnomeCmdData
                    save_dirs_on_exit(FALSE),
                    save_tabs_on_exit(TRUE),
                    save_dir_history_on_exit(TRUE),
+                   save_cmdline_history_on_exit(TRUE),
+                   save_search_history_on_exit(TRUE),
                    symlink_prefix(NULL),
                    size_disp_mode(GNOME_CMD_SIZE_DISP_MODE_POWERED),
                    perm_disp_mode(GNOME_CMD_PERM_DISP_MODE_TEXT),
@@ -484,6 +489,7 @@ struct GnomeCmdData
         gboolean match_case;
 
         Selection(): syntax(Filter::TYPE_REGEX), max_depth(-1), content_search(FALSE), match_case(FALSE)       {}
+        ~Selection() {}
 
         const std::string &description() const    {  return filename_pattern;  }
         void reset();
@@ -502,9 +508,10 @@ struct GnomeCmdData
 
         std::vector<Selection> &profiles;
 
-        SearchConfig(std::vector<Selection> &selections): width(600), height(400), name_patterns(SEARCH_HISTORY_SIZE), content_patterns(SEARCH_HISTORY_SIZE), profiles(selections)   {  default_profile.name = "Default";  }
+        explicit SearchConfig(std::vector<Selection> &selections): width(600), height(400), name_patterns(SEARCH_HISTORY_SIZE), content_patterns(SEARCH_HISTORY_SIZE), profiles(selections)   {  default_profile.name = "Default";  }
 
         friend XML::xstream &operator << (XML::xstream &xml, SearchConfig &cfg);
+        ~SearchConfig() {};
     };
 
     struct AdvrenameConfig
@@ -525,6 +532,7 @@ struct GnomeCmdData
             Profile(): template_string("$N"),
                        counter_start(1), counter_width(1), counter_step(1),
                        case_conversion(0), trim_blanks(3)                     {}
+            ~Profile()                                                        {}
 
             const std::string &description() const {  return template_string;  }
             void reset();
@@ -566,6 +574,8 @@ struct GnomeCmdData
 
     typedef std::pair<std::string,triple<GnomeCmdFileList::ColumnID,GtkSortType,gboolean> > Tab;
 
+    static GSettingsSchemaSource* GetGlobalSchemaSource();
+
     struct Private;
 
     Private *priv;
@@ -638,6 +648,7 @@ struct GnomeCmdData
     void free();                // FIXME: free() -> ~GnomeCmdData()
 
     void load();
+    void gsettings_init();
     void migrate_all_data_to_gsettings();
     gint migrate_data_int_value_into_gsettings(gint user_value, GSettings *settings, const char *key);
     gboolean migrate_data_string_value_into_gsettings(const char* user_value, GSettings *settings, const char *key);
@@ -691,5 +702,3 @@ extern gchar *config_dir;
 
 extern DICT<guint> gdk_key_names;
 extern DICT<guint> gdk_modifiers_names;
-
-#endif // __GNOME_CMD_DATA_H__
