@@ -2,7 +2,7 @@
  * @file gnome-cmd-dir-indicator.cc
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2016 Uwe Scholz\n
+ * @copyright (C) 2013-2017 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -181,7 +181,6 @@ static gint on_dir_indicator_motion (GnomeCmdDirIndicator *indicator, GdkEventMo
 
     // find out where in the label the pointer is at
     gint iX = (gint) event->x;
-    gint iY = (gint) event->y;
 
     for (gint i=0; i < indicator->priv->numPositions; i++)
     {
@@ -362,7 +361,12 @@ void gnome_cmd_dir_indicator_show_history (GnomeCmdDirIndicator *indicator)
                        path);
     }
 
-    gnome_popup_menu_do_popup (indicator->priv->dir_history_popup, (GtkMenuPositionFunc) get_popup_pos, indicator, NULL, NULL, NULL);
+    gnome_popup_menu_do_popup (indicator->priv->dir_history_popup,
+                               (GtkMenuPositionFunc) get_popup_pos,
+                               indicator,
+                               NULL,
+                               NULL,
+                               NULL);
 
     gint w = -1;
 
@@ -409,7 +413,7 @@ void gnome_cmd_dir_indicator_show_bookmarks (GnomeCmdDirIndicator *indicator)
 
     add_menu_item (indicator, GTK_MENU_SHELL (indicator->priv->bookmark_popup), NULL, NULL, indicator);
     add_menu_item (indicator, GTK_MENU_SHELL (indicator->priv->bookmark_popup), _("Add current dir"), GTK_SIGNAL_FUNC (on_bookmarks_add_current), indicator);
-    add_menu_item (indicator, GTK_MENU_SHELL (indicator->priv->bookmark_popup), _("Manage bookmarks..."), GTK_SIGNAL_FUNC (on_bookmarks_manage), indicator);
+    add_menu_item (indicator, GTK_MENU_SHELL (indicator->priv->bookmark_popup), _("Manage bookmarks…"), GTK_SIGNAL_FUNC (on_bookmarks_manage), indicator);
 
     gnome_popup_menu_do_popup (indicator->priv->bookmark_popup, (GtkMenuPositionFunc) get_popup_pos, indicator, NULL, NULL, NULL);
 
@@ -492,7 +496,7 @@ GtkType gnome_cmd_dir_indicator_get_type ()
     if (type == 0)
     {
         GtkTypeInfo info = {
-            "GnomeCmdDirIndicator",
+            (gchar*) "GnomeCmdDirIndicator",
             sizeof(GnomeCmdDirIndicator),
             sizeof(GnomeCmdDirIndicatorClass),
             (GtkClassInitFunc) class_init,
@@ -544,12 +548,11 @@ void gnome_cmd_dir_indicator_set_dir (GnomeCmdDirIndicator *indicator, gchar *pa
 
     const gchar sep = isUNC ? '\\' : G_DIR_SEPARATOR;
     GArray *pos = g_array_sized_new (FALSE, FALSE, sizeof(gint), 16);
-    gint i;
 
     for (s = isUNC ? path+2 : path+1; *s; ++s)
         if (*s==sep)
         {
-            i = s-path;
+            gint i = s-path;
             g_array_append_val (pos, i);
         }
 
@@ -581,10 +584,10 @@ void gnome_cmd_dir_indicator_set_dir (GnomeCmdDirIndicator *indicator, gchar *pa
         indicator->priv->slashPixelPosition[pos_idx++] = get_string_pixel_size (path, 1);
     }
 
-    for (i = isUNC ? 1 : 0; i < pos->len; i++)
+    for (guint ii = isUNC ? 1 : 0; ii < pos->len; ii++)
     {
-        indicator->priv->slashCharPosition[pos_idx] = g_array_index (pos, gint, i);
-        indicator->priv->slashPixelPosition[pos_idx++] = get_string_pixel_size (path, g_array_index (pos, gint, i)+1);
+        indicator->priv->slashCharPosition[pos_idx] = g_array_index (pos, gint, ii);
+        indicator->priv->slashPixelPosition[pos_idx++] = get_string_pixel_size (path, g_array_index (pos, gint, ii)+1);
     }
 
     if (indicator->priv->numPositions>0)
