@@ -2,7 +2,7 @@
  * @file gnome-cmd-dir-indicator.h
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2016 Uwe Scholz\n
+ * @copyright (C) 2013-2017 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,8 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  */
-#ifndef __GNOME_CMD_DIR_INDICATOR_H__
-#define __GNOME_CMD_DIR_INDICATOR_H__
+#pragma once
 
 #include "gnome-cmd-file-selector.h"
 
@@ -58,5 +57,3 @@ void gnome_cmd_dir_indicator_set_active (GnomeCmdDirIndicator *indicator, gboole
 void gnome_cmd_dir_indicator_show_history (GnomeCmdDirIndicator *indicator);
 
 void gnome_cmd_dir_indicator_show_bookmarks (GnomeCmdDirIndicator *indicator);
-
-#endif // __GNOME_CMD_DIR_INDICATOR_H__
