@@ -2,7 +2,7 @@
  * @file gnome-cmd-dir.h
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2016 Uwe Scholz\n
+ * @copyright (C) 2013-2017 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,8 +19,7 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-#ifndef __GNOME_CMD_DIR_H__
-#define __GNOME_CMD_DIR_H__
+#pragma once
 
 #define GNOME_CMD_TYPE_DIR              (gnome_cmd_dir_get_type ())
 #define GNOME_CMD_DIR(obj)              (G_TYPE_CHECK_INSTANCE_CAST((obj), GNOME_CMD_TYPE_DIR, GnomeCmdDir))
@@ -170,5 +169,3 @@ inline gchar *gnome_cmd_dir_get_free_space (GnomeCmdDir *dir)
 
     return gnome_vfs_format_file_size_for_display (free_space);
 }
-
-#endif // __GNOME_CMD_DIR_H__
