@@ -2,7 +2,7 @@
  * @file gnome-cmd-file-collection.h
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2016 Uwe Scholz\n
+ * @copyright (C) 2013-2017 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,9 +19,7 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-#ifndef __GNOME_CMD_FILE_COLLECTION_H__
-#define __GNOME_CMD_FILE_COLLECTION_H__
-
+#pragma once
 
 #include "gnome-cmd-file.h"
 
@@ -72,5 +70,3 @@ inline void GnomeCmdFileCollection::add(GList *files)
     for (; files; files = files->next)
         add(GNOME_CMD_FILE (files->data));
 }
-
-#endif // __GNOME_CMD_FILE_COLLECTION_H__
