@@ -2,7 +2,7 @@
  * @file gnome-cmd-file-list.cc
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2016 Uwe Scholz\n
+ * @copyright (C) 2013-2017 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,6 +30,7 @@
 #include "gnome-cmd-file.h"
 #include "gnome-cmd-con-list.h"
 #include "gnome-cmd-main-win.h"
+#include "gnome-cmd-plain-path.h"
 #include "utils.h"
 #include "gnome-cmd-data.h"
 #include "gnome-cmd-xfer.h"
@@ -91,6 +92,14 @@ static GtkTargetEntry drop_types [] =
 static guint signals[LAST_SIGNAL] = { 0 };
 
 
+struct TmpDlData
+{
+    GnomeCmdFile *f;
+    GtkWidget *dialog;
+    gpointer *args;
+};
+
+
 struct GnomeCmdFileListColumn
 {
     guint id;
@@ -172,7 +181,7 @@ struct GnomeCmdFileList::Private
 
     GtkItemFactory *ifac;
 
-    Private(GnomeCmdFileList *fl);
+    explicit Private(GnomeCmdFileList *fl);
     ~Private();
 
     static gchar *translate_menu(const gchar *path, gpointer);
@@ -213,14 +222,14 @@ GnomeCmdFileList::Private::Private(GnomeCmdFileList *fl)
         gtk_clist_set_column_resizeable (*fl, i, TRUE);
 
     static GtkItemFactoryEntry items[] = {
-                                            {N_("/_Copy here"), "<control>", (GtkItemFactoryCallback) on_dnd_popup_menu, GNOME_VFS_XFER_RECURSIVE, "<StockItem>", GTK_STOCK_COPY},
-                                            {N_("/_Move here"), "<shift>", (GtkItemFactoryCallback) on_dnd_popup_menu, GNOME_VFS_XFER_REMOVESOURCE, "<StockItem>", GTK_STOCK_COPY},
-                                            {N_("/_Link here"), "<control><shift>", (GtkItemFactoryCallback) on_dnd_popup_menu,GNOME_VFS_XFER_LINK_ITEMS,"<StockItem>", GTK_STOCK_CONVERT},
-                                            {"/", NULL, NULL, 0, "<Separator>"},
-                                            {N_("/C_ancel"), "Esc", (GtkItemFactoryCallback) on_dnd_popup_menu, 0, "<StockItem>", GTK_STOCK_CANCEL}
+                                            {(gchar*) N_("/_Copy here"), (gchar*) "<control>", (GtkItemFactoryCallback) on_dnd_popup_menu, GNOME_VFS_XFER_RECURSIVE, (gchar*) "<StockItem>", GTK_STOCK_COPY},
+                                            {(gchar*) N_("/_Move here"), (gchar*) "<shift>", (GtkItemFactoryCallback) on_dnd_popup_menu, GNOME_VFS_XFER_REMOVESOURCE, (gchar*) "<StockItem>", GTK_STOCK_COPY},
+                                            {(gchar*) N_("/_Link here"), (gchar*) "<control><shift>", (GtkItemFactoryCallback) on_dnd_popup_menu,GNOME_VFS_XFER_LINK_ITEMS, (gchar*) "<StockItem>", GTK_STOCK_CONVERT},
+                                            {(gchar*) "/", NULL, NULL, 0, (gchar*) "<Separator>"},
+                                            {(gchar*) N_("/C_ancel"), (gchar*) "Esc", (GtkItemFactoryCallback) on_dnd_popup_menu, 0, (gchar*) "<StockItem>", GTK_STOCK_CANCEL}
                                          };
 
-    ifac = gtk_item_factory_new (GTK_TYPE_MENU, "<main>", NULL);
+    ifac = gtk_item_factory_new (GTK_TYPE_MENU, (const gchar*) "<main>", NULL);
     gtk_item_factory_set_translate_func (ifac, translate_menu, NULL, NULL);
     gtk_item_factory_create_items (ifac, G_N_ELEMENTS (items), items, fl);
 }
@@ -303,7 +312,7 @@ struct FileFormatData
 gchar FileFormatData::empty_string[] = "";
 
 
-inline FileFormatData::FileFormatData(GnomeCmdFileList *fl, GnomeCmdFile *f, gboolean tree_size)
+FileFormatData::FileFormatData(GnomeCmdFileList *fl, GnomeCmdFile *f, gboolean tree_size)
 {
     // If the user wants a character instead of icon for filetype set it now
     if (gnome_cmd_data.options.layout == GNOME_CMD_LAYOUT_TEXT)
@@ -329,11 +338,11 @@ inline FileFormatData::FileFormatData(GnomeCmdFileList *fl, GnomeCmdFile *f, gbo
         fname = get_utf8 (f->get_name());
 
     if (fl->priv->base_dir != NULL)
-	text[GnomeCmdFileList::COLUMN_DIR] = g_strconcat(get_utf8("."), dpath + (strlen(fl->priv->base_dir)-1), NULL);
+        text[GnomeCmdFileList::COLUMN_DIR] = g_strconcat(get_utf8("."), dpath + (strlen(fl->priv->base_dir)-1), NULL);
     else 
-	text[GnomeCmdFileList::COLUMN_DIR] = dpath;
+        text[GnomeCmdFileList::COLUMN_DIR] = dpath;
 
-    DEBUG ('l', "FileFormatData text[GnomeCmdFileList::COLUMN_DIR]=[%s]\n", text[GnomeCmdFileList::COLUMN_DIR]);	
+    DEBUG ('l', "FileFormatData text[GnomeCmdFileList::COLUMN_DIR]=[%s]\n", text[GnomeCmdFileList::COLUMN_DIR]);
 
     if (gnome_cmd_data.options.ext_disp_mode != GNOME_CMD_EXT_DISP_WITH_FNAME)
         fext = get_utf8 (f->get_extension());
@@ -363,7 +372,7 @@ inline FileFormatData::FileFormatData(GnomeCmdFileList *fl, GnomeCmdFile *f, gbo
 }
 
 
-inline FileFormatData::~FileFormatData()
+FileFormatData::~FileFormatData()
 {
     g_free (dpath);
     g_free (fname);
@@ -474,7 +483,7 @@ void GnomeCmdFileList::select_file(GnomeCmdFile *f, gint row)
 
 
     if (!gnome_cmd_data.options.use_ls_colors)
-        gtk_clist_set_row_style (*this, row, row%2 ? alt_sel_list_style : sel_list_style);
+        gtk_clist_set_row_style (*this, row, (row % 2) ? alt_sel_list_style : sel_list_style);
     else
     {
         GnomeCmdColorTheme *colors = gnome_cmd_data.options.get_current_color_theme();
@@ -509,7 +518,7 @@ void GnomeCmdFileList::unselect_file(GnomeCmdFile *f, gint row)
     priv->selected_files.remove(f);
 
     if (!gnome_cmd_data.options.use_ls_colors)
-        gtk_clist_set_row_style (*this, row, row%2 ? alt_list_style : list_style);
+        gtk_clist_set_row_style (*this, row, (row % 2) ? alt_list_style : list_style);
     else
     {
         GnomeCmdColorTheme *colors = gnome_cmd_data.options.get_current_color_theme();
@@ -541,12 +550,13 @@ void GnomeCmdFileList::toggle_file(GnomeCmdFile *f)
     if (row == -1)
         return;
 
-    if (row < priv->visible_files.size())
+    guint real_row = row;
+    if (real_row < priv->visible_files.size())
     {
         if (!priv->selected_files.contain(f))
-            select_file(f, row);
+            select_file(f, real_row);
         else
-            unselect_file(f, row);
+            unselect_file(f, real_row);
     }
 }
 
@@ -610,18 +620,18 @@ static void toggle_files_with_same_extension (GnomeCmdFileList *fl, gboolean sel
 
     for (GList *i=fl->get_visible_files(); i; i=i->next)
     {
-        GnomeCmdFile *f = (GnomeCmdFile *) i->data;
+        GnomeCmdFile *ff = (GnomeCmdFile *) i->data;
 
-        if (f && f->info)
+        if (ff && ff->info)
         {
-            const gchar *ext2 = f->get_extension();
+            const gchar *ext2 = ff->get_extension();
 
             if (ext2 && strcmp (ext1, ext2) == 0)
             {
                 if (select)
-                    fl->select_file(f);
+                    fl->select_file(ff);
                 else
-                    fl->unselect_file(f);
+                    fl->unselect_file(ff);
             }
         }
     }
@@ -1083,7 +1093,7 @@ static gint sort_by_group (GnomeCmdFile *f1, GnomeCmdFile *f2, GnomeCmdFileList
     g_return_if_fail (GNOME_CMD_IS_FILE_LIST (fl));
 
     fl->priv->sort_raising[col] = fl->priv->current_col == col ? !fl->priv->sort_raising[col] :
-                                                                 file_list_column[col].default_sort_direction;
+                                                                 (static_cast<bool>(file_list_column[col].default_sort_direction));
 
     fl->priv->sort_func = file_list_column[col].sort_func;
     fl->priv->current_col = col;
@@ -1110,6 +1120,10 @@ static void on_scroll_vertical (GtkCList *clist, GtkScrollType scroll_type, gflo
         if (start_row < 0 || end_row < 0)
             return;
 
+#if defined (__GNUC__)
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wswitch-enum"
+#endif
         switch (scroll_type)
         {
             case GTK_SCROLL_STEP_BACKWARD:
@@ -1134,6 +1148,9 @@ static void on_scroll_vertical (GtkCList *clist, GtkScrollType scroll_type, gflo
                 break;
         }
     }
+#if defined (__GNUC__)
+#pragma GCC diagnostic pop
+#endif
 
     fl->priv->cur_file = clist->focus_row;
 }
@@ -1168,6 +1185,171 @@ static gboolean on_button_press (GtkCList *clist, GdkEventButton *event, GnomeCm
 }
 
 
+static void do_mime_exec_single (gpointer *args)
+{
+    g_return_if_fail (args != NULL);
+
+    GnomeCmdApp *app = (GnomeCmdApp *) args[0];
+    gchar *path = (gchar *) args[1];
+    gchar *dpath = (gchar *) args[2];
+
+    string cmd = gnome_cmd_app_get_command (app);
+    cmd += ' ';
+    cmd += stringify (g_shell_quote (path));
+
+    run_command_indir (cmd.c_str(), dpath, gnome_cmd_app_get_requires_terminal (app));
+
+    g_free (path);
+    g_free (dpath);
+    gnome_cmd_app_free (app);
+    g_free (args);
+}
+
+
+static void on_tmp_download_response (GtkWidget *w, gint id, TmpDlData *dldata)
+{
+    if (id == GTK_RESPONSE_YES)
+    {
+        gchar *path_str = get_temp_download_filepath (dldata->f->get_name());
+
+        if (!path_str) return;
+
+        dldata->args[1] = (gpointer) path_str;
+
+        GnomeVFSURI *src_uri = gnome_vfs_uri_dup (dldata->f->get_uri());
+        GnomeCmdPlainPath path(path_str);
+        GnomeVFSURI *dest_uri = gnome_cmd_con_create_uri (get_home_con (), &path);
+
+        gnome_cmd_xfer_tmp_download (src_uri,
+                                     dest_uri,
+                                     GNOME_VFS_XFER_FOLLOW_LINKS,
+                                     GNOME_VFS_XFER_OVERWRITE_MODE_REPLACE,
+                                     GTK_SIGNAL_FUNC (do_mime_exec_single),
+                                     dldata->args);
+    }
+    else
+    {
+        gnome_cmd_app_free ((GnomeCmdApp *) dldata->args[0]);
+        g_free (dldata->args);
+    }
+
+    g_free (dldata);
+    gtk_widget_destroy (dldata->dialog);
+}
+
+
+static void mime_exec_single (GnomeCmdFile *f)
+{
+    g_return_if_fail (f != NULL);
+    g_return_if_fail (f->info != NULL);
+
+    gpointer *args;
+    GnomeVFSMimeApplication *vfs_app;
+    GnomeCmdApp *app;
+
+    if (!f->info->mime_type)
+        return;
+
+    // Check if the file is a binary executable that lacks the executable bit
+
+    if (!f->is_executable())
+    {
+        if (f->has_mime_type("application/x-executable") || f->has_mime_type("application/x-executable-binary"))
+        {
+            gchar *fname = get_utf8 (f->info->name);
+            gchar *msg = g_strdup_printf (_("“%s” seems to be a binary executable file but it lacks the executable bit. Do you want to set it and then run the file?"), fname);
+            gint ret = run_simple_dialog (*main_win, FALSE, GTK_MESSAGE_QUESTION, msg,
+                                          _("Make Executable?"),
+                                          -1, _("Cancel"), _("OK"), NULL);
+            g_free (fname);
+            g_free (msg);
+
+            if (ret != 1)  return;  else
+            {
+                GnomeVFSResult result = f->chmod((GnomeVFSFilePermissions) (f->info->permissions|GNOME_VFS_PERM_USER_EXEC));
+                if (result != GNOME_VFS_OK)
+                    return;
+            }
+        }
+    }
+
+    // If the file is executable but not a binary file, check if the user wants to exec it or open it
+
+    if (f->is_executable())
+    {
+        if (f->has_mime_type("application/x-executable") || f->has_mime_type("application/x-executable-binary"))
+        {
+            f->execute();
+            return;
+        }
+        else
+            if (f->mime_begins_with("text/"))
+            {
+                gchar *fname = get_utf8 (f->info->name);
+                gchar *msg = g_strdup_printf (_("“%s” is an executable text file. Do you want to run it, or display its contents?"), fname);
+                gint ret = run_simple_dialog (*main_win, FALSE, GTK_MESSAGE_QUESTION, msg, _("Run or Display"),
+                                              -1, _("Cancel"), _("Display"), _("Run"), NULL);
+                g_free (fname);
+                g_free (msg);
+
+                if (ret != 1)
+                {
+                    if (ret == 2)
+                        f->execute();
+                    return;
+                }
+            }
+    }
+
+    vfs_app = gnome_vfs_mime_get_default_application (f->info->mime_type);
+    if (!vfs_app)
+    {
+        gchar *msg = g_strdup_printf (_("No default application found for the MIME type %s."), f->info->mime_type);
+        gnome_cmd_show_message (NULL, msg, "Open the \"File types and programs\" page in the Control Center to add one.");
+        g_free (msg);
+        return;
+    }
+
+    app = gnome_cmd_app_new_from_vfs_app (vfs_app);
+    gnome_vfs_mime_application_free (vfs_app);
+
+    args = g_new0 (gpointer, 3);
+
+    if (f->is_local())
+    {
+        args[0] = (gpointer) app;
+        args[1] = (gpointer) f->get_real_path();
+        args[2] = (gpointer) g_path_get_dirname ((gchar *) args[1]);            // set exec dir for local files
+        do_mime_exec_single (args);
+    }
+    else
+    {
+        if (gnome_cmd_app_get_handles_uris (app) && gnome_cmd_data.options.honor_expect_uris)
+        {
+            args[0] = (gpointer) app;
+            args[1] = (gpointer) f->get_uri_str();
+            // args[2] is NULL here (don't set exec dir for remote files)
+            do_mime_exec_single (args);
+        }
+        else
+        {
+            gchar *msg = g_strdup_printf (_("%s does not know how to open remote file. Do you want to download the file to a temporary location and then open it?"), gnome_cmd_app_get_name (app));
+            GtkWidget *dialog = gtk_message_dialog_new (*main_win, GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, "%s", msg);
+            TmpDlData *dldata = g_new0 (TmpDlData, 1);
+            args[0] = (gpointer) app;
+            // args[2] is NULL here (don't set exec dir for temporarily downloaded files)
+            dldata->f = f;
+            dldata->dialog = dialog;
+            dldata->args = args;
+
+            g_signal_connect (dialog, "response", G_CALLBACK (on_tmp_download_response), dldata);
+            gtk_widget_show (dialog);
+            g_free (msg);
+        }
+    }
+}
+
+
 inline gboolean mime_exec_file (GnomeCmdFile *f)
 {
     g_return_val_if_fail (f != NULL, FALSE);
@@ -1685,7 +1867,7 @@ inline void add_file_to_clist (GnomeCmdFileList *fl, GnomeCmdFile *f, gint in_ro
 
     // Setup row data and color
     if (!gnome_cmd_data.options.use_ls_colors)
-        gtk_clist_set_row_style (clist, row, row%2 ? alt_list_style : list_style);
+        gtk_clist_set_row_style (clist, row, (row % 2) ? alt_list_style : list_style);
     else
     {
         LsColor *col = ls_colors_get (f);
@@ -1985,12 +2167,12 @@ void GnomeCmdFileList::toggle_and_step()
 
     if (f)
         toggle_file(f);
-    if (priv->cur_file < size()-1)
+    if (priv->cur_file < (gint)size()-1)
         focus_file_at_row (this, priv->cur_file+1);
 }
 
 
-void GnomeCmdFileList::focus_file(const gchar *focus_file, gboolean scroll_to_file)
+void GnomeCmdFileList::focus_file(const gchar *file_to_focus, gboolean scroll_to_file)
 {
     for (GList *i=get_visible_files(); i; i=i->next)
     {
@@ -2003,7 +2185,7 @@ void GnomeCmdFileList::focus_file(const gchar *focus_file, gboolean scroll_to_fi
         if (row == -1)
             return;
 
-        if (strcmp (f->info->name, focus_file) == 0)
+        if (strcmp (f->info->name, file_to_focus) == 0)
         {
             priv->cur_file = row;
             focus_file_at_row (this, row);
@@ -2016,7 +2198,7 @@ void GnomeCmdFileList::focus_file(const gchar *focus_file, gboolean scroll_to_fi
     /* The file was not found, remember the filename in case the file gets
        added to the list in the future (after a FAM event etc). */
     g_free (priv->focus_later);
-    priv->focus_later = g_strdup (focus_file);
+    priv->focus_later = g_strdup (file_to_focus);
 }
 
 
@@ -2274,9 +2456,13 @@ gboolean GnomeCmdFileList::key_pressed(GdkEventKey *event)
             case GDK_KP_Subtract:
                 toggle_files_with_same_extension (this, FALSE);
                 break;
+
+            default:
+                break;
         }
     }
-    else if (state_is_ctrl_alt (event->state) || state_is_ctrl_alt_shift (event->state))
+    else if ((gnome_cmd_data.options.quick_search == GNOME_CMD_QUICK_SEARCH_CTRL_ALT)
+             && (state_is_ctrl_alt (event->state) || state_is_ctrl_alt_shift (event->state)))
     {
         if ((event->keyval >= GDK_a && event->keyval <= GDK_z)
             || (event->keyval >= GDK_A && event->keyval <= GDK_Z)
@@ -2343,6 +2529,9 @@ gboolean GnomeCmdFileList::key_pressed(GdkEventKey *event)
                 priv->shift_down = TRUE;
                 g_signal_emit_by_name (this, "scroll-vertical", GTK_SCROLL_JUMP, 1.0);
                 return TRUE;
+
+            default:
+                break;
         }
     }
     else if (state_is_alt_shift (event->state))
@@ -2353,6 +2542,8 @@ gboolean GnomeCmdFileList::key_pressed(GdkEventKey *event)
             case GDK_KP_Enter:
                 show_visible_tree_sizes();
                 return TRUE;
+            default:
+                break;
         }
     }
     else if (state_is_ctrl (event->state))
@@ -2384,6 +2575,9 @@ gboolean GnomeCmdFileList::key_pressed(GdkEventKey *event)
             case GDK_F6:
                 on_column_clicked (*this, COLUMN_SIZE, this);
                 return TRUE;
+
+            default:
+                break;
         }
     }
     else if (state_is_blank (event->state))
@@ -2468,6 +2662,9 @@ gboolean GnomeCmdFileList::key_pressed(GdkEventKey *event)
             case GDK_Menu:
                 show_file_popup_with_warp (this);
                 return TRUE;
+
+            default:
+                break;
         }
     }
 
@@ -2595,6 +2792,9 @@ void GnomeCmdFileList::set_directory(GnomeCmdDir *dir)
             else
                 on_dir_list_ok (dir, NULL, this);
             break;
+
+        default:
+            break;
     }
 
     gnome_cmd_dir_start_monitoring (dir);
@@ -2811,7 +3011,7 @@ static void unref_uri_list (GList *list)
 }
 
 
-void free_dnd_popup_data (gpointer *data)
+static void free_dnd_popup_data (gpointer *data)
 {
     if (data)
     {
@@ -2861,6 +3061,10 @@ static void drag_data_received (GtkWidget *widget, GdkDragContext *context, gint
     GnomeVFSXferOptions xferOptions;
 
     // find out what operation to perform
+#if defined (__GNUC__)
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wswitch-enum"
+#endif
     switch (context->action)
     {
         case GDK_ACTION_MOVE:
@@ -2879,6 +3083,9 @@ static void drag_data_received (GtkWidget *widget, GdkDragContext *context, gint
             g_warning ("Unknown context->action in drag_data_received");
             return;
     }
+#if defined (__GNUC__)
+#pragma GCC diagnostic pop
+#endif
 
     fl->drop_files(xferOptions,uri_list,to);
 }
