@@ -32,6 +32,9 @@
 #include "gnome-cmd-user-actions.h"
 #include "utils.h"
 #include "cap.h"
+#include "gnome-cmd-con-list.h"
+#include "gnome-cmd-plain-path.h"
+#include "gnome-cmd-xfer.h"
 
 #include <fnmatch.h>
 
@@ -66,6 +69,113 @@ struct GnomeCmdFilePopmenuPrivate
 };
 
 
+static void do_mime_exec_multiple (gpointer *args)
+{
+    GnomeCmdApp *app = (GnomeCmdApp *) args[0];
+    GList *files = (GList *) args[1];
+
+    if (files)
+    {
+        string cmd = gnome_cmd_app_get_command (app);
+
+        set<string> dirs;
+
+        for (; files; files = files->next)
+        {
+            cmd += ' ';
+            cmd += stringify (g_shell_quote ((gchar *) files->data));
+
+            gchar *dpath = g_path_get_dirname ((gchar *) files->data);
+
+            if (dpath)
+                dirs.insert (stringify (dpath));
+        }
+
+        if (dirs.size()==1)
+            run_command_indir (cmd.c_str(), dirs.begin()->c_str(), gnome_cmd_app_get_requires_terminal (app));
+        else
+            run_command_indir (cmd.c_str(), NULL, gnome_cmd_app_get_requires_terminal (app));
+
+        g_list_free (files);
+    }
+
+    gnome_cmd_app_free (app);
+    g_free (args);
+}
+
+
+static void mime_exec_multiple (GList *files, GnomeCmdApp *app)
+{
+    g_return_if_fail (files != NULL);
+    g_return_if_fail (app != NULL);
+
+    GList *src_uri_list = NULL;
+    GList *dest_uri_list = NULL;
+    GList *local_files = NULL;
+    gboolean asked = FALSE;
+    guint no_of_remote_files = 0;
+    gint retid;
+
+    for (; files; files = files->next)
+    {
+        GnomeCmdFile *f = (GnomeCmdFile *) files->data;
+
+        if (gnome_vfs_uri_is_local (f->get_uri()))
+            local_files = g_list_append (local_files, f->get_real_path());
+        else
+        {
+            ++no_of_remote_files;
+            if (gnome_cmd_app_get_handles_uris (app) && gnome_cmd_data.options.honor_expect_uris)
+            {
+                local_files = g_list_append (local_files,  f->get_uri_str());
+            }
+            else
+            {
+                if (!asked)
+                {
+                    gchar *msg = g_strdup_printf (ngettext("%s does not know how to open remote file. Do you want to download the file to a temporary location and then open it?",
+                                                           "%s does not know how to open remote files. Do you want to download the files to a temporary location and then open them?", no_of_remote_files),
+                                                  gnome_cmd_app_get_name (app));
+                    retid = run_simple_dialog (*main_win, TRUE, GTK_MESSAGE_QUESTION, msg, "", -1, _("No"), _("Yes"), NULL);
+                    asked = TRUE;
+                }
+
+                if (retid==1)
+                {
+                    gchar *path_str = get_temp_download_filepath (f->get_name());
+
+                    if (!path_str) return;
+
+                    GnomeVFSURI *src_uri = gnome_vfs_uri_dup (f->get_uri());
+                    GnomeCmdPlainPath path(path_str);
+                    GnomeVFSURI *dest_uri = gnome_cmd_con_create_uri (get_home_con (), &path);
+
+                    src_uri_list = g_list_append (src_uri_list, src_uri);
+                    dest_uri_list = g_list_append (dest_uri_list, dest_uri);
+                    local_files = g_list_append (local_files, path_str);
+                }
+            }
+        }
+    }
+
+    g_list_free (files);
+
+    gpointer *args = g_new0 (gpointer, 2);
+    args[0] = app;
+    args[1] = local_files;
+
+    if (src_uri_list)
+        gnome_cmd_xfer_tmp_download_multiple (src_uri_list,
+                                              dest_uri_list,
+                                              GNOME_VFS_XFER_FOLLOW_LINKS,
+                                              GNOME_VFS_XFER_OVERWRITE_MODE_REPLACE,
+                                              GTK_SIGNAL_FUNC (do_mime_exec_multiple),
+                                              args);
+    else
+        do_mime_exec_multiple (args);
+}
+
+
 inline void exec_with_app (GList *files, GnomeCmdApp *app)
 {
     mime_exec_multiple (files, app);
@@ -119,7 +229,7 @@ static void cb_exec_default (GtkMenuItem *menu_item, GList *files)
             data->files = g_list_append (data->files, f);
         }
         else
-            gnome_cmd_show_message (NULL, f->info->name, _("Couldn't retrieve MIME type of the file."));
+            gnome_cmd_show_message (NULL, f->info->name, _("Couldn’t retrieve MIME type of the file."));
     }
 
     g_hash_table_foreach (hash, (GHFunc) htcb_exec_with_app, NULL);
@@ -161,7 +271,7 @@ static void on_open_with_other (GtkMenuItem *menu_item, GList *files)
     const gchar *labels[] = {_("Application:")};
     GtkWidget *dialog;
 
-    dialog = gnome_cmd_string_dialog_new (_("Open with other..."), labels, 1,
+    dialog = gnome_cmd_string_dialog_new (_("Open with other…"), labels, 1,
                                           (GnomeCmdStringDialogCallback) on_open_with_other_ok, files);
 
     g_return_if_fail (GNOME_CMD_IS_STRING_DIALOG (dialog));
@@ -352,6 +462,9 @@ inline gboolean fav_app_matches_files (GnomeCmdApp *app, GList *files)
                 if (!ok) return FALSE;
             }
             return TRUE;
+
+        default:
+            break;
     }
 
     return FALSE;
@@ -468,7 +581,7 @@ inline gchar *get_default_application_action_name (GList *files, gchar **icon_pa
 
     gchar *escaped_app_name = string_double_underscores (app->name);
     gnome_vfs_mime_application_free (app);
-    gchar *retval = g_strdup_printf (_("_Open with \"%s\""), escaped_app_name);
+    gchar *retval = g_strdup_printf (_("_Open with “%s”"), escaped_app_name);
     g_free (escaped_app_name);
 
     return retval;
@@ -482,7 +595,7 @@ inline gchar *get_default_application_action_name (GList *files, gchar **icon_pa
 GtkWidget *gnome_cmd_file_popmenu_new (GnomeCmdFileList *fl)
 {
     gint pos, match_count;
-    GList *vfs_apps, *tmp;
+    GList *vfs_apps, *tmp_list;
 
     // Make place for separator and open with other...
     static GnomeUIInfo apps_uiinfo[MAX_OPEN_WITH_APPS+2];
@@ -517,7 +630,7 @@ GtkWidget *gnome_cmd_file_popmenu_new (GnomeCmdFileList *fl)
         GNOMEUIINFO_ITEM_STOCK(N_("Send files"), NULL, file_sendto, GTK_STOCK_EXECUTE),
         GNOMEUIINFO_ITEM_FILENAME (N_("Open _terminal here"), NULL, command_open_terminal__internal, PIXMAPS_DIR G_DIR_SEPARATOR_S  "terminal.svg"),
         GNOMEUIINFO_SEPARATOR,
-        GNOMEUIINFO_ITEM_STOCK(N_("_Properties..."), NULL, on_properties, GTK_STOCK_PROPERTIES),
+        GNOMEUIINFO_ITEM_STOCK(N_("_Properties…"), NULL, on_properties, GTK_STOCK_PROPERTIES),
         GNOMEUIINFO_END
     };
 
@@ -534,7 +647,7 @@ GtkWidget *gnome_cmd_file_popmenu_new (GnomeCmdFileList *fl)
     gint i = -1;
     menu->priv->data_list = NULL;
 
-    vfs_apps = tmp = gnome_vfs_mime_get_all_applications (f->info->mime_type);
+    vfs_apps = tmp_list = gnome_vfs_mime_get_all_applications (f->info->mime_type);
     for (; vfs_apps && i < MAX_OPEN_WITH_APPS; vfs_apps = vfs_apps->next)
     {
         GnomeVFSMimeApplication *vfs_app = (GnomeVFSMimeApplication *) vfs_apps->data;
@@ -563,22 +676,22 @@ GtkWidget *gnome_cmd_file_popmenu_new (GnomeCmdFileList *fl)
 
     // Add open with other
     apps_uiinfo[++i].type = GNOME_APP_UI_ITEM;
-    apps_uiinfo[i].label = g_strdup (_("Other _Application..."));
+    apps_uiinfo[i].label = g_strdup (_("Other _Application…"));
     apps_uiinfo[i].moreinfo = (gpointer) on_open_with_other;
     apps_uiinfo[i].user_data = files;
     apps_uiinfo[i].pixmap_type = GNOME_APP_PIXMAP_NONE;
 
-    gnome_vfs_mime_application_list_free (tmp);
+    gnome_vfs_mime_application_list_free (tmp_list);
     apps_uiinfo[++i].type = GNOME_APP_UI_ENDOFINFO;
 
     // Set default callback data
-    for (gint i=0; open_uiinfo[i].type != GNOME_APP_UI_ENDOFINFO; ++i)
-        if (open_uiinfo[i].type == GNOME_APP_UI_ITEM)
-            open_uiinfo[i].user_data = fl;
+    for (gint j=0; open_uiinfo[j].type != GNOME_APP_UI_ENDOFINFO; ++j)
+        if (open_uiinfo[j].type == GNOME_APP_UI_ITEM)
+            open_uiinfo[j].user_data = fl;
 
-    for (gint i=0; other_uiinfo[i].type != GNOME_APP_UI_ENDOFINFO; ++i)
-        if (other_uiinfo[i].type == GNOME_APP_UI_ITEM)
-            other_uiinfo[i].user_data = fl;
+    for (gint j=0; other_uiinfo[j].type != GNOME_APP_UI_ENDOFINFO; ++j)
+        if (other_uiinfo[j].type == GNOME_APP_UI_ITEM)
+            other_uiinfo[j].user_data = fl;
 
     open_uiinfo[0].label = get_default_application_action_name(files, (gchar **) &open_uiinfo[0].pixmap_info);  // must be freed after gnome_app_fill_menu ()
     open_uiinfo[0].pixmap_type = open_uiinfo[0].pixmap_info ? GNOME_APP_PIXMAP_FILENAME : GNOME_APP_PIXMAP_NONE;
@@ -599,9 +712,9 @@ GtkWidget *gnome_cmd_file_popmenu_new (GnomeCmdFileList *fl)
 
     // Add favorite applications
     match_count = 0;
-    for (GList *i=gnome_cmd_data.options.fav_apps; i; i = i->next)
+    for (GList *j=gnome_cmd_data.options.fav_apps; j; j = j->next)
     {
-        GnomeCmdApp *app = (GnomeCmdApp *) i->data;
+        GnomeCmdApp *app = (GnomeCmdApp *) j->data;
         if (fav_app_matches_files (app, files))
         {
             add_fav_app_menu_item (menu, app, pos++, files);
@@ -609,9 +722,9 @@ GtkWidget *gnome_cmd_file_popmenu_new (GnomeCmdFileList *fl)
         }
     }
 
-    for (GList *i=plugin_manager_get_all (); i; i = i->next)
+    for (GList *j=plugin_manager_get_all (); j; j = j->next)
     {
-        PluginData *data = (PluginData *) i->data;
+        PluginData *data = (PluginData *) j->data;
         if (data->active)
         {
             GList *items = gnome_cmd_plugin_create_popup_menu_items (data->plugin, main_win->get_state());
@@ -669,7 +782,7 @@ GtkWidget *gnome_cmd_file_popmenu_new (GnomeCmdFileList *fl)
     if (dp != NULL)
     {
         struct dirent *ep;
-        while (ep = readdir (dp))
+        while ((ep = readdir (dp)))
         {
             struct stat buf;
             string s (user_dir);
@@ -699,11 +812,11 @@ GtkWidget *gnome_cmd_file_popmenu_new (GnomeCmdFileList *fl)
             string s (user_dir);
             s.append ("/").append ((char*) l->data);
 
-            FILE *f = fopen (s.c_str (), "r");
-            if (f)
+            FILE *ff = fopen (s.c_str (), "r");
+            if (ff)
             {
                 char buf[256];
-                while (fgets (buf, 256, f))
+                while (fgets (buf, 256, ff))
                 {
                     if (strncmp (buf, "#name:", 6) == 0)
                     {
@@ -716,7 +829,7 @@ GtkWidget *gnome_cmd_file_popmenu_new (GnomeCmdFileList *fl)
                         data->term = strncmp (buf + 7, "true", 4) == 0;
                     }
                 }
-                fclose (f);
+                fclose (ff);
             }
 
             data->name = g_strdup (s.c_str ());
@@ -754,7 +867,7 @@ GtkType gnome_cmd_file_popmenu_get_type ()
     {
         GtkTypeInfo dlg_info =
         {
-            "GnomeCmdFilePopmenu",
+            (gchar*) "GnomeCmdFilePopmenu",
             sizeof (GnomeCmdFilePopmenu),
             sizeof (GnomeCmdFilePopmenuClass),
             (GtkClassInitFunc) class_init,
