@@ -2,7 +2,7 @@
  * @file gnome-cmd-file.h
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2016 Uwe Scholz\n
+ * @copyright (C) 2013-2017 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,8 +19,7 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-#ifndef __GNOME_CMD_FILE_H__
-#define __GNOME_CMD_FILE_H__
+#pragma once
 
 #define GNOME_CMD_TYPE_FILE              (gnome_cmd_file_get_type ())
 #define GNOME_CMD_FILE(obj)              (G_TYPE_CHECK_INSTANCE_CAST((obj), GNOME_CMD_TYPE_FILE, GnomeCmdFile))
@@ -204,5 +203,3 @@ inline GnomeVFSMimeApplication *GnomeCmdFile::get_default_application()
 {
     return info->mime_type ? gnome_vfs_mime_get_default_application (info->mime_type) : NULL;
 }
-
-#endif // __GNOME_CMD_FILE_H__
