@@ -2,7 +2,7 @@
  * @file gnome-cmd-hintbox.cc
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2016 Uwe Scholz\n
+ * @copyright (C) 2013-2017 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -257,6 +257,10 @@ gnome_cmd_label_set_attributes (GtkLabel *label, ...)
     {
       PangoAttrType   attr_type = ( PangoAttrType) va_arg (args, gint);
 
+#if defined (__GNUC__)
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wswitch-enum"
+#endif
       switch (attr_type)
         {
         case PANGO_ATTR_LANGUAGE:
@@ -331,11 +335,16 @@ gnome_cmd_label_set_attributes (GtkLabel *label, ...)
         default:
           g_warning ("%s: invalid PangoAttribute type %d",
                      G_STRFUNC, attr_type);
-        case -1:
+#if defined (__GNUC__) && __GNUC__ >= 7
+          __attribute__ ((fallthrough));
+#endif
         case PANGO_ATTR_INVALID:
           attr = NULL;
           break;
         }
+#if defined (__GNUC__)
+#pragma GCC diagnostic pop
+#endif
 
       if (attr)
         {
