@@ -2,7 +2,7 @@
  * @file gnome-cmd-main-menu.cc
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2016 Uwe Scholz\n
+ * @copyright (C) 2013-2017 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -148,8 +148,11 @@ static GtkWidget *create_menu_item (GnomeCmdMainMenu *main_menu, GtkMenu *parent
     GtkWidget *desc=NULL;
     GtkWidget *shortcut=NULL;
     GtkWidget *content = NULL;
-    GtkWidget *pixmap = NULL;
 
+#if defined (__GNUC__)
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wswitch-enum"
+#endif
     switch (spec->type)
     {
         case MENU_TYPE_BASIC:
@@ -176,6 +179,7 @@ static GtkWidget *create_menu_item (GnomeCmdMainMenu *main_menu, GtkMenu *parent
 
             if (spec->pixmap_type != 0 && spec->pixmap_info)
             {
+                GtkWidget *pixmap = NULL;
                 pixmap = create_ui_pixmap (*main_win, spec->pixmap_type, spec->pixmap_info, GTK_ICON_SIZE_MENU);
 
                 if (pixmap)
@@ -214,6 +218,9 @@ static GtkWidget *create_menu_item (GnomeCmdMainMenu *main_menu, GtkMenu *parent
             g_warning ("This MENU_TYPE is not implemented");
             return NULL;
     }
+#if defined (__GNUC__)
+#pragma GCC diagnostic pop
+#endif
 
     gtk_widget_show (item);
 
@@ -413,26 +420,26 @@ static void init (GnomeCmdMainMenu *main_menu)
             NULL
         },
         {
-            MENU_TYPE_ITEM, _("_Properties..."), "Alt+ENTER", NULL,
+            MENU_TYPE_ITEM, _("_Properties…"), "Alt+ENTER", NULL,
             (gpointer) file_properties, NULL,
             GNOME_APP_PIXMAP_STOCK, GTK_STOCK_PROPERTIES,
             NULL
         },
         MENUTYPE_SEPARATOR,
         {
-            MENU_TYPE_ITEM, _("_Search..."), "Alt+F7", NULL,
+            MENU_TYPE_ITEM, _("_Search…"), "Alt+F7", NULL,
             (gpointer) edit_search, NULL,
             GNOME_APP_PIXMAP_STOCK, GTK_STOCK_FIND,
             NULL
         },
         {
-            MENU_TYPE_ITEM, _("_Quick Search..."), "", NULL,
+            MENU_TYPE_ITEM, _("_Quick Search…"), "", NULL,
             (gpointer) edit_quick_search, NULL,
             GNOME_APP_PIXMAP_NONE, 0,
             NULL
         },
         {
-            MENU_TYPE_ITEM, _("_Enable Filter..."), "", NULL,
+            MENU_TYPE_ITEM, _("_Enable Filter…"), "", NULL,
             (gpointer) edit_filter, NULL,
             GNOME_APP_PIXMAP_NONE, 0,
             NULL
@@ -659,13 +666,13 @@ static void init (GnomeCmdMainMenu *main_menu)
     MenuData bookmarks_menu_uiinfo[] =
     {
         {
-            MENU_TYPE_ITEM, _("_Bookmark this Directory..."), "", NULL,
+            MENU_TYPE_ITEM, _("_Bookmark this Directory…"), "", NULL,
             (gpointer) bookmarks_add_current, NULL,
             GNOME_APP_PIXMAP_STOCK, GTK_STOCK_ADD,
             NULL
         },
         {
-            MENU_TYPE_ITEM, _("_Manage Bookmarks..."), "Ctrl+D", NULL,
+            MENU_TYPE_ITEM, _("_Manage Bookmarks…"), "Ctrl+D", NULL,
             (gpointer) bookmarks_edit, NULL,
             GNOME_APP_PIXMAP_NONE, NULL,
             NULL
@@ -677,7 +684,7 @@ static void init (GnomeCmdMainMenu *main_menu)
     MenuData plugins_menu_uiinfo[] =
     {
         {
-            MENU_TYPE_ITEM, _("_Configure Plugins..."), "", NULL,
+            MENU_TYPE_ITEM, _("_Configure Plugins…"), "", NULL,
             (gpointer) plugins_configure, NULL,
             GNOME_APP_PIXMAP_DATA, exec_wheel_xpm,
             NULL
@@ -689,13 +696,13 @@ static void init (GnomeCmdMainMenu *main_menu)
     MenuData options_menu_uiinfo[] =
     {
         {
-            MENU_TYPE_ITEM, _("_Options..."), "Ctrl+O", NULL,
+            MENU_TYPE_ITEM, _("_Options…"), "Ctrl+O", NULL,
             (gpointer) options_edit, NULL,
             GNOME_APP_PIXMAP_STOCK, GTK_STOCK_PREFERENCES,
             NULL
         },
         {
-            MENU_TYPE_ITEM, _("_Keyboard Shortcuts..."), "", NULL,
+            MENU_TYPE_ITEM, _("_Keyboard Shortcuts…"), "", NULL,
             (gpointer) options_edit_shortcuts, NULL,
             GNOME_APP_PIXMAP_STOCK, GTK_STOCK_ITALIC,
             NULL
@@ -706,13 +713,13 @@ static void init (GnomeCmdMainMenu *main_menu)
     MenuData connections_menu_uiinfo[] =
     {
         {
-            MENU_TYPE_ITEM, _("_Remote Server..."), "Ctrl+F", NULL,
+            MENU_TYPE_ITEM, _("_Remote Server…"), "Ctrl+F", NULL,
             (gpointer) connections_open, NULL,
             GNOME_APP_PIXMAP_STOCK, GTK_STOCK_CONNECT,
             NULL
         },
         {
-            MENU_TYPE_ITEM, _("New Connection..."), "Ctrl+N", NULL,
+            MENU_TYPE_ITEM, _("New Connection…"), "Ctrl+N", NULL,
             (gpointer) connections_new, NULL,
             GNOME_APP_PIXMAP_STOCK, GTK_STOCK_CONNECT,
             NULL
@@ -844,7 +851,7 @@ GtkType gnome_cmd_main_menu_get_type ()
     {
         GtkTypeInfo dlg_info =
         {
-            "GnomeCmdMainMenu",
+            (gchar*) "GnomeCmdMainMenu",
             sizeof (GnomeCmdMainMenu),
             sizeof (GnomeCmdMainMenuClass),
             (GtkClassInitFunc) class_init,
