@@ -2,7 +2,7 @@
  * @file gnome-cmd-menu-button.h
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2016 Uwe Scholz\n
+ * @copyright (C) 2013-2017 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,13 +19,10 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-#ifndef __GNOME_CMD_MENU_BUTTON_H__
-#define __GNOME_CMD_MENU_BUTTON_H__
+#pragma once
 
 GtkWidget *gnome_cmd_button_menu_new (const gchar *label, GtkWidget *menu);
 GtkWidget *gnome_cmd_button_menu_new_from_stock (const gchar *stock_id, GtkWidget *menu);
 GtkWidget *gnome_cmd_button_menu_new_from_stock (const gchar *stock_id, const gchar *label, GtkWidget *menu);
 gulong gnome_cmd_button_menu_connect_handler (GtkWidget *button, GtkWidget *menu);
 void gnome_cmd_button_menu_disconnect_handler (GtkWidget *button, GtkWidget *menu);
-
-#endif // __GNOME_CMD_MENU_BUTTON_H__
