@@ -2,7 +2,7 @@
  * @file gnome-cmd-notebook.h
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2016 Uwe Scholz\n
+ * @copyright (C) 2013-2017 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,8 +19,7 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-#ifndef __GNOME_CMD_NOTEBOOK_H__
-#define __GNOME_CMD_NOTEBOOK_H__
+#pragma once
 
 #include <gtk/gtk.h>
 
@@ -59,7 +58,7 @@ struct GnomeCmdNotebook
 
     TabBarVisibility tabs_visibility;
 
-    GnomeCmdNotebook(TabBarVisibility visibility=HIDE_TABS_IF_ONE);
+    explicit GnomeCmdNotebook(TabBarVisibility visibility=HIDE_TABS_IF_ONE);
 
     int size() const                    {  return gtk_notebook_get_n_pages (*this);       }
     bool empty() const                  {  return size()==0;                              }
@@ -70,12 +69,12 @@ struct GnomeCmdNotebook
     GtkWidget *page() const             {  return gtk_notebook_get_nth_page (*this, get_current_page());  }
     GtkWidget *page(gint n) const       {  return gtk_notebook_get_nth_page (*this, n);   }
 
-    gint insert_page(GtkWidget *page, gint n, GtkWidget *label=NULL);
-    gint insert_page(GtkWidget *page, gint n, const gchar *label)           {  return insert_page(page, n, label ? gtk_label_new (label) : NULL);  }
-    gint prepend_page(GtkWidget *page, GtkWidget *label=NULL)               {  return insert_page(page, 0, label);                                 }
-    gint prepend_page(GtkWidget *page, const gchar *label)                  {  return insert_page(page, 0, label);   }
-    gint append_page(GtkWidget *page, GtkWidget *label=NULL)                {  return insert_page(page, -1, label);                                }
-    gint append_page(GtkWidget *page, const gchar *label)                   {  return insert_page(page, -1, label);  }
+    gint insert_page(GtkWidget *page_insert, gint n, GtkWidget *label=NULL);
+    gint insert_page(GtkWidget *page_insert, gint n, const gchar *label)    {  return insert_page(page_insert, n, label ? gtk_label_new (label) : NULL);  }
+    gint prepend_page(GtkWidget *page_prepend, GtkWidget *label=NULL)       {  return insert_page(page_prepend, 0, label);                                 }
+    gint prepend_page(GtkWidget *page_prepend, const gchar *label)          {  return insert_page(page_prepend, 0, label);   }
+    gint append_page(GtkWidget *page_append, GtkWidget *label=NULL)         {  return insert_page(page_append, -1, label);                                }
+    gint append_page(GtkWidget *page_append, const gchar *label)            {  return insert_page(page_append, -1, label);  }
 
     void remove_page(gint n);
     void remove_page()                                                      {  remove_page (get_current_page());                                   }
@@ -96,11 +95,11 @@ struct GnomeCmdNotebook
     int find_tab_num_at_pos(gint screen_x, gint screen_y) const;
 };
 
-inline gint GnomeCmdNotebook::insert_page(GtkWidget *page, gint n, GtkWidget *label)
+inline gint GnomeCmdNotebook::insert_page(GtkWidget *page_insert, gint n, GtkWidget *label)
 {
     if (tabs_visibility==HIDE_TABS_IF_ONE && size()==1)
         gtk_notebook_set_show_tabs (*this, TRUE);
-    return gtk_notebook_insert_page (*this, page, label, n);
+    return gtk_notebook_insert_page (*this, page_insert, label, n);
 }
 
 inline void GnomeCmdNotebook::remove_page(gint n)
@@ -129,5 +128,3 @@ inline void GnomeCmdNotebook::next_page()
         if (n>1)
             set_current_page(0);
 }
-
-#endif // __GNOME_CMD_NOTEBOOK_H__
