@@ -196,6 +196,9 @@ static gboolean on_key_pressed_after (GtkWidget *entry, GdkEventKey *event, Gnom
                 }
             }
             break;
+
+        default:
+            break;
     }
 
     if (popup->priv->pos)
@@ -306,7 +309,7 @@ GtkType gnome_cmd_quicksearch_popup_get_type ()
     {
         GtkTypeInfo info =
         {
-            "GnomeCmdQuicksearchPopup",
+            (gchar*) "GnomeCmdQuicksearchPopup",
             sizeof (GnomeCmdQuicksearchPopup),
             sizeof (GnomeCmdQuicksearchPopupClass),
             (GtkClassInitFunc) class_init,
