@@ -2,7 +2,7 @@
  * @file gnome-cmd-smb-net.cc
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2016 Uwe Scholz\n
+ * @copyright (C) 2013-2017 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -119,7 +119,7 @@ static gboolean str_ncase_equal (gchar *a, gchar *b)
 }
 
 
-guint str_hash (gchar *key)
+static guint str_hash (gchar *key)
 {
     gchar *s = g_ascii_strup (key, strlen (key));
     gint i = g_str_hash (s);
