@@ -2,7 +2,7 @@
  * @file gnome-cmd-smb-path.h
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2016 Uwe Scholz\n
+ * @copyright (C) 2013-2017 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,8 +19,7 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-#ifndef __GNOME_CMD_SMB_PATH_H__
-#define __GNOME_CMD_SMB_PATH_H__
+#pragma once
 
 #include "gnome-cmd-path.h"
 
@@ -42,7 +41,7 @@ class GnomeCmdSmbPath: public GnomeCmdPath
 
     GnomeCmdSmbPath(const GnomeCmdSmbPath &thePath);
     GnomeCmdSmbPath(const gchar *workgroup, const gchar *resource, const gchar *path);
-    GnomeCmdSmbPath(const gchar *path_str);
+    explicit GnomeCmdSmbPath(const gchar *path_str);
     virtual ~GnomeCmdSmbPath();
 
     virtual const gchar *get_path()                 {  return path;                   }
@@ -68,5 +67,3 @@ inline GnomeCmdSmbPath::~GnomeCmdSmbPath()
     g_free (path);
     g_free (display_path);
 }
-
-#endif // __GNOME_CMD_SMB_PATH_H__
