@@ -2,7 +2,7 @@
  * @file gnome-cmd-treeview.h
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2016 Uwe Scholz\n
+ * @copyright (C) 2013-2017 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,8 +19,7 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-#ifndef __GNOME_CMD_TREEVIEW_H__
-#define __GNOME_CMD_TREEVIEW_H__
+#pragma once
 
 GtkTreeViewColumn *gnome_cmd_treeview_create_new_text_column (GtkTreeView *view, GtkCellRenderer *&renderer, gint COL_ID, const gchar *title=NULL);
 GtkTreeViewColumn *gnome_cmd_treeview_create_new_pixbuf_column (GtkTreeView *view, GtkCellRenderer *&renderer, gint COL_ID, const gchar *title=NULL);
@@ -32,5 +31,3 @@ inline GtkTreeViewColumn *gnome_cmd_treeview_create_new_text_column (GtkTreeView
 
     return gnome_cmd_treeview_create_new_text_column (view, renderer, COL_ID, title);
 }
-
-#endif // __GNOME_CMD_TREEVIEW_H__
