@@ -2,7 +2,7 @@
  * @file gnome-cmd-user-actions.cc
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2016 Uwe Scholz\n
+ * @copyright (C) 2013-2017 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,9 +19,8 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-#include <gtk/gtkclipboard.h>
+#include <gtk/gtk.h>
 #include <libgnome/gnome-util.h>
-#include <libgnomeui/gnome-url.h>
 #include <set>
 #include <algorithm>
 
@@ -98,8 +97,16 @@ GcmdUserActionSettings *gcmd_user_action_settings_new ()
 
 static void gcmd_user_action_settings_init (GcmdUserActionSettings *gs)
 {
-    gs->filter = g_settings_new (GCMD_PREF_FILTER);
-    gs->general = g_settings_new (GCMD_PREF_GENERAL);
+    GSettingsSchemaSource   *global_schema_source;
+    GSettingsSchema         *global_schema;
+
+    global_schema_source = GnomeCmdData::GetGlobalSchemaSource();
+
+    global_schema = g_settings_schema_source_lookup (global_schema_source, GCMD_PREF_FILTER, FALSE);
+    gs->filter = g_settings_new_full (global_schema, NULL, NULL);
+
+    global_schema = g_settings_schema_source_lookup (global_schema_source, GCMD_PREF_GENERAL, FALSE);
+    gs->general = g_settings_new_full (global_schema, NULL, NULL);
 }
 
 /***********************************
@@ -121,7 +128,7 @@ inline GnomeCmdFileList *get_fl (const FileSelectorID fsID)
 
 
 // The file returned from this function is not to be unrefed
-inline GnomeCmdFile *get_selected_file (const FileSelectorID fsID)
+static GnomeCmdFile *get_selected_file (const FileSelectorID fsID)
 {
     GnomeCmdFile *f = get_fl (fsID)->get_first_selected_file();
 
@@ -141,7 +148,7 @@ inline gboolean append_real_path (string &s, const gchar *name)
 }
 
 
-inline gboolean append_real_path (string &s, GnomeCmdFile *f)
+static gboolean append_real_path (string &s, GnomeCmdFile *f)
 {
     if (!f)
         return FALSE;
@@ -169,11 +176,7 @@ inline bool operator < (const GdkEventKey &e1, const GdkEventKey &e2)
     if (e1.keyval > e2.keyval)
         return false;
 
-#if GTK_CHECK_VERSION (2, 10, 0)
     return (e1.state & (GDK_SHIFT_MASK | GDK_CONTROL_MASK | GDK_MOD1_MASK | GDK_SUPER_MASK | GDK_HYPER_MASK | GDK_META_MASK)) < (e2.state & (GDK_SHIFT_MASK | GDK_CONTROL_MASK | GDK_MOD1_MASK | GDK_SUPER_MASK | GDK_HYPER_MASK | GDK_META_MASK));
-#else
-    return (e1.state & (GDK_SHIFT_MASK | GDK_CONTROL_MASK | GDK_MOD1_MASK | GDK_MOD4_MASK)) < (e2.state & (GDK_SHIFT_MASK | GDK_CONTROL_MASK | GDK_MOD1_MASK | GDK_MOD4_MASK));
-#endif
 }
 
 
@@ -322,21 +325,13 @@ void GnomeCmdUserActions::init()
     if (!registered("connections.change_left"))
     {
         register_action(GDK_MOD1_MASK, GDK_1, "connections.change_left");
-#if GTK_CHECK_VERSION (2, 10, 0)
         register_action(GDK_SUPER_MASK, GDK_1, "connections.change_left");
-#else
-        register_action(GDK_MOD4_MASK, GDK_1, "connections.change_left");
-#endif
     }
 
     if (!registered("connections.change_right"))
     {
         register_action(GDK_MOD1_MASK, GDK_2, "connections.change_right");
-#if GTK_CHECK_VERSION (2, 10, 0)
         register_action(GDK_SUPER_MASK, GDK_2, "connections.change_right");
-#else
-        register_action(GDK_MOD4_MASK, GDK_2, "connections.change_right");
-#endif
     }
 
     if (!registered("edit.copy_filenames"))
@@ -348,11 +343,7 @@ void GnomeCmdUserActions::init()
     if (!registered("edit.search"))
     {
         register_action(GDK_MOD1_MASK, GDK_F7, "edit.search");
-#if GTK_CHECK_VERSION (2, 10, 0)
         register_action(GDK_SUPER_MASK, GDK_F, "edit.search");
-#else
-        register_action(GDK_MOD4_MASK, GDK_F, "edit.search");
-#endif
     }
 
     if (!registered("file.advrename"))
@@ -497,9 +488,9 @@ void GnomeCmdUserActions::shutdown()
 }
 
 
-gboolean GnomeCmdUserActions::register_action(guint state, guint keyval, const gchar *name, const char *user_data)
+gboolean GnomeCmdUserActions::register_action(guint state, guint keyval, const gchar *action_name, const char *user_data)
 {
-    GnomeCmdUserActionFunc func = action_func[name];
+    GnomeCmdUserActionFunc func = action_func[action_name];
 
     if (!func)
         return FALSE;
@@ -507,11 +498,7 @@ gboolean GnomeCmdUserActions::register_action(guint state, guint keyval, const g
     GdkEventKey event;
 
     event.keyval = keyval;
-#if GTK_CHECK_VERSION (2, 10, 0)
     event.state = state & (GDK_SHIFT_MASK | GDK_CONTROL_MASK | GDK_MOD1_MASK | GDK_SUPER_MASK | GDK_HYPER_MASK | GDK_META_MASK);
-#else
-    event.state = state & (GDK_SHIFT_MASK | GDK_CONTROL_MASK | GDK_MOD1_MASK | GDK_MOD4_MASK);
-#endif
     if (action.find(event)!=action.end())
         return FALSE;
 
@@ -529,7 +516,7 @@ gboolean GnomeCmdUserActions::register_action(guint state, guint keyval, const g
 }
 
 
-void GnomeCmdUserActions::unregister(const gchar *name)
+void GnomeCmdUserActions::unregister(const gchar *action_name)
 {
 }
 
@@ -539,11 +526,7 @@ void GnomeCmdUserActions::unregister(guint state, guint keyval)
     GdkEventKey event;
 
     event.keyval = keyval;
-#if GTK_CHECK_VERSION (2, 10, 0)
     event.state = state & (GDK_SHIFT_MASK | GDK_CONTROL_MASK | GDK_MOD1_MASK | GDK_SUPER_MASK | GDK_HYPER_MASK | GDK_META_MASK);
-#else
-    event.state = state & (GDK_SHIFT_MASK | GDK_CONTROL_MASK | GDK_MOD1_MASK | GDK_MOD4_MASK);
-#endif
     map <GdkEventKey, UserAction>::iterator pos = action.find(event);
 
     if (pos!=action.end())
@@ -551,9 +534,9 @@ void GnomeCmdUserActions::unregister(guint state, guint keyval)
 }
 
 
-gboolean GnomeCmdUserActions::registered(const gchar *name)
+gboolean GnomeCmdUserActions::registered(const gchar *action_name)
 {
-    GnomeCmdUserActionFunc func = action_func[name];
+    GnomeCmdUserActionFunc func = action_func[action_name];
 
     if (!func)
         return FALSE;
@@ -571,11 +554,7 @@ gboolean GnomeCmdUserActions::registered(guint state, guint keyval)
     GdkEventKey event;
 
     event.keyval = keyval;
-#if GTK_CHECK_VERSION (2, 10, 0)
     event.state = state & (GDK_SHIFT_MASK | GDK_CONTROL_MASK | GDK_MOD1_MASK | GDK_SUPER_MASK | GDK_HYPER_MASK | GDK_META_MASK);
-#else
-    event.state = state & (GDK_SHIFT_MASK | GDK_CONTROL_MASK | GDK_MOD1_MASK | GDK_MOD4_MASK);
-#endif
 
     return action.find(event)!=action.end();
 }
@@ -614,13 +593,9 @@ XML::xstream &operator << (XML::xstream &xml, GnomeCmdUserActions &usr)
             if (state & GDK_SHIFT_MASK)    xml << XML::attr("shift") << 1;
             if (state & GDK_CONTROL_MASK)  xml << XML::attr("control") << 1;
             if (state & GDK_MOD1_MASK)     xml << XML::attr("alt") << 1;
-#if GTK_CHECK_VERSION (2, 10, 0)
             if (state & GDK_SUPER_MASK)    xml << XML::attr("super") << 1;
             if (state & GDK_HYPER_MASK)    xml << XML::attr("hyper") << 1;
             if (state & GDK_META_MASK)     xml << XML::attr("meta") << 1;
-#else
-            if (state & GDK_MOD4_MASK)     xml << XML::attr("super") << 1;
-#endif
 
             xml << XML::attr("action") << usr.action_func[i->second.func];
             if (!i->second.user_data.empty())
@@ -689,7 +664,7 @@ GtkTreeModel *gnome_cmd_user_actions_create_model ()
 
 
 template <typename F>
-inline void get_file_list (string &s, GList *sfl, F f)
+static void get_file_list (string &s, GList *sfl, F f)
 {
     vector<string> a;
 
@@ -787,7 +762,6 @@ void file_edit (GtkMenuItem *menuitem, gpointer not_used)
         gnome_cmd_file_selector_show_new_textfile_dialog (get_fs (ACTIVE));
     else
     {
-	GnomeCmdDir *dir = NULL;
 	gchar       *command;
 
 	command = g_strdup (gnome_cmd_data.options.editor);
@@ -805,6 +779,7 @@ void file_edit (GtkMenuItem *menuitem, gpointer not_used)
 	}
 	else
 	{
+        GnomeCmdDir *dir = NULL;
 	    gint     argc;
 	    gchar  **argv  = NULL;
 	    GError  *error = NULL;
@@ -891,8 +866,8 @@ void file_create_symlink (GtkMenuItem *menuitem, gpointer not_used)
     }
    else
    {
-        GnomeCmdFile *f = get_fl (ACTIVE)->get_focused_file();
-        gnome_cmd_file_selector_create_symlink (inactive_fs, f);
+        GnomeCmdFile *focused_f = get_fl (ACTIVE)->get_focused_file();
+        gnome_cmd_file_selector_create_symlink (inactive_fs, focused_f);
    }
 }
 
@@ -932,7 +907,6 @@ void file_advrename (GtkMenuItem *menuitem, gpointer not_used)
 
 void file_sendto (GtkMenuItem *menuitem, gpointer not_used)
 {
-    GnomeCmdDir  *dir     = NULL;
     gchar        *command = NULL;
     string        dir_path;
     string        cmd;
@@ -950,6 +924,7 @@ void file_sendto (GtkMenuItem *menuitem, gpointer not_used)
     }
     else
     {
+    GnomeCmdDir *dir = NULL;
 	gint     argc;
 	gchar  **argv  = NULL;
 	GError  *error = NULL;
@@ -981,7 +956,7 @@ void file_diff (GtkMenuItem *menuitem, gpointer not_used)
 
     GList *sel_files = active_fl->get_selected_files();
 
-    string s;
+    string files_to_differ;
 
     switch (g_list_length (sel_files))
     {
@@ -992,8 +967,8 @@ void file_diff (GtkMenuItem *menuitem, gpointer not_used)
             if (!get_fs (INACTIVE)->is_local())
                 gnome_cmd_show_message (*main_win, _("Operation not supported on remote file systems"));
             else
-                if (!append_real_path (s, get_selected_file (ACTIVE)) || !append_real_path (s, get_selected_file (INACTIVE)))
-                    s.clear();
+                if (!append_real_path (files_to_differ, get_selected_file (ACTIVE)) || !append_real_path (files_to_differ, get_selected_file (INACTIVE)))
+                    files_to_differ.clear();
             break;
 
         case 2:
@@ -1001,7 +976,7 @@ void file_diff (GtkMenuItem *menuitem, gpointer not_used)
             sel_files = active_fl->sort_selection(sel_files);
 
             for (GList *i = sel_files; i; i = i->next)
-                append_real_path (s, GNOME_CMD_FILE (i->data));
+                append_real_path (files_to_differ, GNOME_CMD_FILE (i->data));
             break;
 
         default:
@@ -1011,9 +986,16 @@ void file_diff (GtkMenuItem *menuitem, gpointer not_used)
 
     g_list_free (sel_files);
 
-    if (!s.empty())
+    if (!files_to_differ.empty())
     {
-        gchar *cmd = g_strdup_printf (gnome_cmd_data.options.differ, s.c_str(), "");
+#if defined (__GNUC__)
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wformat-nonliteral"
+#endif
+        gchar *cmd = g_strdup_printf (gnome_cmd_data.options.differ, files_to_differ.c_str(), "");
+#if defined (__GNUC__)
+#pragma GCC diagnostic pop
+#endif
 
         run_command (cmd);
 
@@ -1038,7 +1020,14 @@ void file_sync_dirs (GtkMenuItem *menuitem, gpointer not_used)
     append_real_path (s, GNOME_CMD_FILE (active_fs->get_directory()));
     append_real_path (s, GNOME_CMD_FILE (inactive_fs->get_directory()));
 
+#if defined (__GNUC__)
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wformat-nonliteral"
+#endif
     gchar *cmd = g_strdup_printf (gnome_cmd_data.options.differ, s.c_str(), "");
+#if defined (__GNUC__)
+#pragma GCC diagnostic pop
+#endif
 
     run_command (cmd);
 
@@ -1050,6 +1039,10 @@ void file_exit (GtkMenuItem *menuitem, gpointer not_used)
 {
     gint x, y;
 
+#if defined (__GNUC__)
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wswitch-enum"
+#endif
     switch (gnome_cmd_data.main_win_state)
     {
         case GDK_WINDOW_STATE_MAXIMIZED:
@@ -1062,6 +1055,9 @@ void file_exit (GtkMenuItem *menuitem, gpointer not_used)
             gnome_cmd_data_set_main_win_pos (x, y);
             break;
     }
+#if defined (__GNUC__)
+#pragma GCC diagnostic pop
+#endif
 
     gtk_widget_destroy (*main_win);
 }
@@ -1532,6 +1528,22 @@ void view_horizontal_orientation (GtkMenuItem *menuitem, gpointer not_used)
     g_settings_set_boolean (gcmd_user_actions.settings->general, GCMD_SETTINGS_HORIZONTAL_ORIENTATION, checkitem->active);
 }
 
+void view_step_up (GtkMenuItem *menuitem, gpointer not_used)
+{
+    GnomeCmdFileSelector *fs = get_fs (ACTIVE);
+    GnomeCmdFileList *fl = fs->file_list();
+
+    g_signal_emit_by_name (fl, "scroll-vertical", GTK_SCROLL_STEP_BACKWARD, 0.0, NULL);
+}
+
+void view_step_down (GtkMenuItem *menuitem, gpointer not_used)
+{
+    GnomeCmdFileSelector *fs = get_fs (ACTIVE);
+    GnomeCmdFileList *fl = fs->file_list();
+
+    g_signal_emit_by_name (fl, "scroll-vertical", GTK_SCROLL_STEP_FORWARD, 0.0, NULL);
+}
+
 void view_up (GtkMenuItem *menuitem, gpointer not_used)
 {
     GnomeCmdFileSelector *fs = get_fs (ACTIVE);
@@ -1552,23 +1564,6 @@ void view_main_menu (GtkMenuItem *menuitem, gpointer not_used)
     g_settings_set_boolean (gcmd_user_actions.settings->general, GCMD_SETTINGS_MAINMENU_VISIBILITY, !mainmenu_visibility);
 }
 
-void view_step_up (GtkMenuItem *menuitem, gpointer not_used)
-{
-    GnomeCmdFileSelector *fs = get_fs (ACTIVE);
-    GnomeCmdFileList *fl = fs->file_list();
-
-    g_signal_emit_by_name (fl, "scroll-vertical", GTK_SCROLL_STEP_BACKWARD, 0.0, NULL);
-}
-
-void view_step_down (GtkMenuItem *menuitem, gpointer not_used)
-{
-    GnomeCmdFileSelector *fs = get_fs (ACTIVE);
-    GnomeCmdFileList *fl = fs->file_list();
-
-    g_signal_emit_by_name (fl, "scroll-vertical", GTK_SCROLL_STEP_FORWARD, 0.0, NULL);
-}
-
-
 void view_first (GtkMenuItem *menuitem, gpointer not_used)
 {
     get_fs (ACTIVE)->first();
@@ -2003,13 +1998,8 @@ void help_web (GtkMenuItem *menuitem, gpointer not_used)
 {
     GError *error = NULL;
 
-#if GTK_CHECK_VERSION (2, 14, 0)
     if (!gtk_show_uri (NULL, "http://gcmd.github.io/", GDK_CURRENT_TIME, &error))
         gnome_cmd_error_message (_("There was an error opening home page."), error);
-#else
-    if (!gnome_url_show ("http://gcmd.github.io/", &error))
-        gnome_cmd_error_message (_("There was an error opening home page."), error);
-#endif
 }
 
 
@@ -2017,13 +2007,8 @@ void help_problem (GtkMenuItem *menuitem, gpointer not_used)
 {
     GError *error = NULL;
 
-#if GTK_CHECK_VERSION (2, 14, 0)
     if (!gtk_show_uri (NULL, "http://bugzilla.gnome.org/browse.cgi?product=gnome-commander", GDK_CURRENT_TIME, &error))
         gnome_cmd_error_message (_("There was an error reporting problem."), error);
-#else
-    if (!gnome_url_show("http://bugzilla.gnome.org/browse.cgi?product=gnome-commander", &error))
-        gnome_cmd_error_message (_("There was an error reporting problem."), error);
-#endif
 }
 
 
@@ -2047,7 +2032,7 @@ void help_about (GtkMenuItem *menuitem, gpointer not_used)
 
     static const gchar copyright[] = "Copyright \xc2\xa9 2001-2006 Marcus Bjurman\n"
                                      "Copyright \xc2\xa9 2007-2012 Piotr Eljasiak\n"
-                                     "Copyright \xc2\xa9 2013-2016 Uwe Scholz";
+                                     "Copyright \xc2\xa9 2013-2017 Uwe Scholz";
 
     static const gchar comments[] = N_("A fast and powerful file manager for the GNOME desktop");
 
@@ -2249,6 +2234,10 @@ int parse_command(string *cmd, gchar *command)
 		}
                 *cmd += '%';
 		cmdlen = cmd->length();
+#if defined (__GNUC__) && __GNUC__ >= 7
+		__attribute__ ((fallthrough));
+#endif
+
             case '%':           // %%  percent sign
 		if (cmdcap < cmdlen + 1)
 		{
