@@ -2,7 +2,7 @@
  * @file gnome-cmd-xfer-progress-win.cc
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2016 Uwe Scholz\n
+ * @copyright (C) 2013-2017 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -39,7 +39,7 @@ static GtkWindowClass *parent_class = NULL;
 static void on_cancel (GtkButton *btn, GnomeCmdXferProgressWin *win)
 {
     win->cancel_pressed = TRUE;
-    gnome_cmd_xfer_progress_win_set_action (win, _("stopping..."));
+    gnome_cmd_xfer_progress_win_set_action (win, _("stopping…"));
     gtk_widget_set_sensitive (GTK_WIDGET (win), FALSE);
 }
 
@@ -139,7 +139,7 @@ GtkType gnome_cmd_xfer_progress_win_get_type ()
     {
         GtkTypeInfo dlg_info =
         {
-            "GnomeCmdXferProgressWin",
+            (gchar*) "GnomeCmdXferProgressWin",
             sizeof (GnomeCmdXferProgressWin),
             sizeof (GnomeCmdXferProgressWinClass),
             (GtkClassInitFunc) class_init,
