@@ -2,7 +2,7 @@
  * @file gnome-cmd-xfer.cc
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2016 Uwe Scholz\n
+ * @copyright (C) 2013-2017 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -128,10 +128,10 @@ create_xfer_data (GnomeVFSXferOptions xferOptions, GList *src_uri_list, GList *d
     // The async_xfer_callback-results for file and byte totals are not reliable
     if (xferOptions == GNOME_VFS_XFER_REMOVESOURCE) {
         GList *uris;
-        GnomeVFSURI *uri;
         data->bytes_total = 0;
         data->files_total = 0;
         for (uris = data->src_uri_list; uris != NULL; uris = uris->next) {
+            GnomeVFSURI *uri;
             uri = (GnomeVFSURI*)uris->data;
             data->bytes_total += calc_tree_size(uri,&(data->files_total));
         }
@@ -196,8 +196,6 @@ static gint async_xfer_callback (GnomeVFSAsyncHandle *handle, GnomeVFSXferProgre
         gchar *source_details = file_details (info->source_name);
         gchar *target_details = file_details (info->target_name);
 
-        GtkWidget *msg;
-
         gchar *text = g_strdup_printf (_("Overwrite file:\n\n<b>%s</b>\n<span color='dimgray' size='smaller'>%s</span>\n\nWith:\n\n<b>%s</b>\n<span color='dimgray' size='smaller'>%s</span>"), target_filename, target_details, source_filename, source_details);
 
         g_free (source_filename);
@@ -265,7 +263,7 @@ static gboolean update_xfer_gui_func (XferData *data)
     {
         if (data->prev_phase != GNOME_VFS_XFER_PHASE_COPYING)
         {
-            gnome_cmd_xfer_progress_win_set_action (data->win, _("copying..."));
+            gnome_cmd_xfer_progress_win_set_action (data->win, _("copying…"));
             data->prev_file = -1;
         }
 
@@ -273,7 +271,7 @@ static gboolean update_xfer_gui_func (XferData *data)
         {
             gchar *t = str_uri_basename (data->cur_file_name);
             gchar *fn = get_utf8 (t);
-            gchar *msg = g_strdup_printf (_("[file %ld of %ld] \"%s\""), data->cur_file, data->files_total, fn);
+            gchar *msg = g_strdup_printf (_("[file %ld of %ld] “%s”"), data->cur_file, data->files_total, fn);
 
             gnome_cmd_xfer_progress_win_set_msg (data->win, msg);
 
@@ -465,7 +463,7 @@ gnome_cmd_xfer_uris_start (GList *src_uri_list,
 
     data->win = GNOME_CMD_XFER_PROGRESS_WIN (gnome_cmd_xfer_progress_win_new (num_files));
     gtk_widget_ref (GTK_WIDGET (data->win));
-    gtk_window_set_title (GTK_WINDOW (data->win), _("preparing..."));
+    gtk_window_set_title (GTK_WINDOW (data->win), _("preparing…"));
     gtk_widget_show (GTK_WIDGET (data->win));
 
     //  start the transfer
@@ -554,6 +552,10 @@ gnome_cmd_xfer_tmp_download_multiple (GList *src_uri_list,
                                    XFER_PRIORITY,
                                    (GnomeVFSAsyncXferProgressCallback) async_xfer_callback, data,
                                    NULL, NULL);
+    if (result != GNOME_VFS_OK)
+    {
+        DEBUG ('x', "Downloading could not be started properly as of wrong arguments in gnome_vfs_async_xfer()\n");
+    }
 
     g_timeout_add (gnome_cmd_data.gui_update_rate, (GSourceFunc) update_xfer_gui_func, data);
 }
