@@ -2,7 +2,7 @@
  * @file gnome-cmd-xml-config.cc
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2016 Uwe Scholz\n
+ * @copyright (C) 2013-2017 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -40,277 +40,6 @@ using namespace std;
 gchar *XML::xstream::escaped_text = NULL;
 
 
-#if !GLIB_CHECK_VERSION (2, 16, 0)
-enum GMarkupCollectType
-{
-  G_MARKUP_COLLECT_INVALID,
-  G_MARKUP_COLLECT_STRING,
-  G_MARKUP_COLLECT_STRDUP,
-  G_MARKUP_COLLECT_BOOLEAN,
-  G_MARKUP_COLLECT_TRISTATE,
-
-  G_MARKUP_COLLECT_OPTIONAL = (1 << 16)
-};
-
-
-static gboolean
-g_markup_parse_boolean (const char  *string,
-                        gboolean    *value)
-{
-  char const * const falses[] = { "false", "f", "no", "n", "0" };
-  char const * const trues[] = { "true", "t", "yes", "y", "1" };
-  int i;
-
-  for (i = 0; i < G_N_ELEMENTS (falses); i++)
-    {
-      if (g_ascii_strcasecmp (string, falses[i]) == 0)
-        {
-          if (value != NULL)
-            *value = FALSE;
-
-          return TRUE;
-        }
-    }
-
-  for (i = 0; i < G_N_ELEMENTS (trues); i++)
-    {
-      if (g_ascii_strcasecmp (string, trues[i]) == 0)
-        {
-          if (value != NULL)
-            *value = TRUE;
-
-          return TRUE;
-        }
-    }
-
-  return FALSE;
-}
-
-
-static
-gboolean
-g_markup_collect_attributes (const gchar         *element_name,
-                             const gchar        **attribute_names,
-                             const gchar        **attribute_values,
-                             GError             **error,
-                             GMarkupCollectType   first_type,
-                             const gchar         *first_attr,
-                             ...)
-{
-  GMarkupCollectType type;
-  const gchar *attr;
-  guint64 collected;
-  int written;
-  va_list ap;
-  int i;
-
-  type = first_type;
-  attr = first_attr;
-  collected = 0;
-  written = 0;
-
-  va_start (ap, first_attr);
-  while (type != G_MARKUP_COLLECT_INVALID)
-    {
-      gboolean mandatory;
-      const gchar *value;
-
-      mandatory = !(type & G_MARKUP_COLLECT_OPTIONAL);
-      type &= (G_MARKUP_COLLECT_OPTIONAL - 1);
-
-      /* tristate records a value != TRUE and != FALSE
-       * for the case where the attribute is missing
-       */
-      if (type == G_MARKUP_COLLECT_TRISTATE)
-        mandatory = FALSE;
-
-      for (i = 0; attribute_names[i]; i++)
-        if (i >= 40 || !(collected & (G_GUINT64_CONSTANT(1) << i)))
-          if (!strcmp (attribute_names[i], attr))
-            break;
-
-      /* ISO C99 only promises that the user can pass up to 127 arguments.
-       * Subtracting the first 4 arguments plus the final NULL and dividing
-       * by 3 arguments per collected attribute, we are left with a maximum
-       * number of supported attributes of (127 - 5) / 3 = 40.
-       *
-       * In reality, nobody is ever going to call us with anywhere close to
-       * 40 attributes to collect, so it is safe to assume that if i > 40
-       * then the user has given some invalid or repeated arguments.  These
-       * problems will be caught and reported at the end of the function.
-       *
-       * We know at this point that we have an error, but we don't know
-       * what error it is, so just continue...
-       */
-      if (i < 40)
-        collected |= (G_GUINT64_CONSTANT(1) << i);
-
-      value = attribute_values[i];
-
-      if (value == NULL && mandatory)
-        {
-          g_set_error (error, G_MARKUP_ERROR,
-                       G_MARKUP_ERROR_MISSING_ATTRIBUTE,
-                       "element '%s' requires attribute '%s'",
-                       element_name, attr);
-
-          va_end (ap);
-          goto failure;
-        }
-
-      switch (type)
-        {
-        case G_MARKUP_COLLECT_STRING:
-          {
-            const char **str_ptr;
-
-            str_ptr = va_arg (ap, const char **);
-
-            if (str_ptr != NULL)
-              *str_ptr = value;
-          }
-          break;
-
-        case G_MARKUP_COLLECT_STRDUP:
-          {
-            char **str_ptr;
-
-            str_ptr = va_arg (ap, char **);
-
-            if (str_ptr != NULL)
-              *str_ptr = g_strdup (value);
-          }
-          break;
-
-        case G_MARKUP_COLLECT_BOOLEAN:
-        case G_MARKUP_COLLECT_TRISTATE:
-          if (value == NULL)
-            {
-              gboolean *bool_ptr;
-
-              bool_ptr = va_arg (ap, gboolean *);
-
-              if (bool_ptr != NULL)
-                {
-                  if (type == G_MARKUP_COLLECT_TRISTATE)
-                    /* constructivists rejoice!
-                     * neither false nor true...
-                     */
-                    *bool_ptr = -1;
-
-                  else /* G_MARKUP_COLLECT_BOOLEAN */
-                    *bool_ptr = FALSE;
-                }
-            }
-          else
-            {
-              if (!g_markup_parse_boolean (value, va_arg (ap, gboolean *)))
-                {
-                  g_set_error (error, G_MARKUP_ERROR,
-                               G_MARKUP_ERROR_INVALID_CONTENT,
-                               "element '%s', attribute '%s', value '%s' "
-                               "cannot be parsed as a boolean value",
-                               element_name, attr, value);
-
-                  va_end (ap);
-                  goto failure;
-                }
-            }
-
-          break;
-
-        default:
-          g_assert_not_reached ();
-        }
-
-      type = va_arg (ap, GMarkupCollectType);
-      attr = va_arg (ap, const char *);
-      written++;
-    }
-  va_end (ap);
-
-  /* ensure we collected all the arguments */
-  for (i = 0; attribute_names[i]; i++)
-    if ((collected & (G_GUINT64_CONSTANT(1) << i)) == 0)
-      {
-        /* attribute not collected:  could be caused by two things.
-         *
-         * 1) it doesn't exist in our list of attributes
-         * 2) it existed but was matched by a duplicate attribute earlier
-         *
-         * find out.
-         */
-        int j;
-
-        for (j = 0; j < i; j++)
-          if (strcmp (attribute_names[i], attribute_names[j]) == 0)
-            /* duplicate! */
-            break;
-
-        /* j is now the first occurance of attribute_names[i] */
-        if (i == j)
-          g_set_error (error, G_MARKUP_ERROR,
-                       G_MARKUP_ERROR_UNKNOWN_ATTRIBUTE,
-                       "attribute '%s' invalid for element '%s'",
-                       attribute_names[i], element_name);
-        else
-          g_set_error (error, G_MARKUP_ERROR,
-                       G_MARKUP_ERROR_INVALID_CONTENT,
-                       "attribute '%s' given multiple times for element '%s'",
-                       attribute_names[i], element_name);
-
-        goto failure;
-      }
-
-  return TRUE;
-
-failure:
-  /* replay the above to free allocations */
-  type = first_type;
-  attr = first_attr;
-
-  va_start (ap, first_attr);
-  while (type != G_MARKUP_COLLECT_INVALID)
-    {
-      gpointer ptr;
-
-      ptr = va_arg (ap, gpointer);
-
-      if (ptr == NULL)
-        continue;
-
-      switch (type & (G_MARKUP_COLLECT_OPTIONAL - 1))
-        {
-        case G_MARKUP_COLLECT_STRDUP:
-          if (written)
-            g_free (*(char **) ptr);
-
-        case G_MARKUP_COLLECT_STRING:
-          *(char **) ptr = NULL;
-          break;
-
-        case G_MARKUP_COLLECT_BOOLEAN:
-          *(gboolean *) ptr = FALSE;
-          break;
-
-        case G_MARKUP_COLLECT_TRISTATE:
-          *(gboolean *) ptr = -1;
-          break;
-        }
-
-      type = va_arg (ap, GMarkupCollectType);
-      attr = va_arg (ap, const char *);
-
-      if (written)
-        written--;
-    }
-  va_end (ap);
-
-  return FALSE;
-}
-#endif
-
-
 enum {XML_ELEM_NOT_FOUND,
       XML_GNOMECOMMANDER,
       XML_GNOMECOMMANDER_LAYOUT,
@@ -624,8 +353,10 @@ static void xml_start(GMarkupParseContext *context,
                                              G_MARKUP_COLLECT_BOOLEAN, "match-case", &param4,
                                              G_MARKUP_COLLECT_BOOLEAN | G_MARKUP_COLLECT_OPTIONAL, "content-search", &param5,
                                              G_MARKUP_COLLECT_INVALID))
+            {
                 xml_search_profile.match_case = param4;
                 xml_search_profile.content_search = param5;
+            }
             break;
 
         case XML_GNOMECOMMANDER_KEYBINDINGS_KEY:
@@ -640,10 +371,8 @@ static void xml_start(GMarkupParseContext *context,
                                                  G_MARKUP_COLLECT_BOOLEAN | G_MARKUP_COLLECT_OPTIONAL, "control", &control,
                                                  G_MARKUP_COLLECT_BOOLEAN | G_MARKUP_COLLECT_OPTIONAL, "alt", &alt,
                                                  G_MARKUP_COLLECT_BOOLEAN | G_MARKUP_COLLECT_OPTIONAL, "super", &super,
-#if GTK_CHECK_VERSION (2, 10, 0)
                                                  G_MARKUP_COLLECT_BOOLEAN | G_MARKUP_COLLECT_OPTIONAL, "hyper", &hyper,
                                                  G_MARKUP_COLLECT_BOOLEAN | G_MARKUP_COLLECT_OPTIONAL, "meta", &meta,
-#endif
                                                  G_MARKUP_COLLECT_INVALID))
                     {
                         if (gcmd_user_actions.has_action(param2))
@@ -661,13 +390,9 @@ static void xml_start(GMarkupParseContext *context,
                                 if (shift)  accel_mask |= GDK_SHIFT_MASK;
                                 if (control)  accel_mask |= GDK_CONTROL_MASK;
                                 if (alt)  accel_mask |= GDK_MOD1_MASK;
-#if GTK_CHECK_VERSION (2, 10, 0)
                                 if (super)  accel_mask |= GDK_SUPER_MASK;
                                 if (hyper)  accel_mask |= GDK_HYPER_MASK;
                                 if (meta)  accel_mask |= GDK_META_MASK;
-#else
-                                if (super)  accel_mask |= GDK_MOD4_MASK;
-#endif
                                 gcmd_user_actions.register_action(accel_mask, keyval, param2, param3);
                             }
                             else
@@ -843,7 +568,7 @@ gboolean gnome_cmd_xml_config_parse (const gchar *xml, gsize xml_len, GnomeCmdDa
     xml_fs_names.add(LEFT,"left");
     xml_fs_names.add(RIGHT,"right");
 
-    if (xml_len==-1)
+    if (xml_len==(gsize)-1)
         xml_len = strlen (xml);
 
     GMarkupParseContext *context = g_markup_parse_context_new (&parser, GMarkupParseFlags(0), &cfg, NULL);
