@@ -2,7 +2,7 @@
  * @file handle.h
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2016 Uwe Scholz\n
+ * @copyright (C) 2013-2017 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,8 +19,7 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-#ifndef __HANDLE_H__
-#define __HANDLE_H__
+#pragma once
 
 struct Handle
 {
@@ -68,5 +67,3 @@ inline gpointer handle_get_ref (Handle *h)
 
     return h->ref;
 }
-
-#endif // __HANDLE_H__
