@@ -2,7 +2,7 @@
  * @file imageloader.cc
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2016 Uwe Scholz\n
+ * @copyright (C) 2013-2017 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -106,11 +106,11 @@ void IMAGE_init ()
         {
             gchar *path2 = g_build_filename ("../pixmaps", pixmap_files[i], NULL);
 
-            g_warning (_("Couldn't load installed file type pixmap, trying to load %s instead"), path2);
+            g_warning (_("Couldn’t load installed file type pixmap, trying to load %s instead"), path2);
 
             pixmaps[i] = gnome_cmd_pixmap_new_from_file (path2);
             if (!pixmaps[i])
-                g_warning (_("Can't find the pixmap anywhere. Make sure you have installed the program or is executing gnome-commander from the gnome-commander-%s/src directory"), VERSION);
+                g_warning (_("Can’t find the pixmap anywhere. Make sure you have installed the program or is executing gnome-commander from the gnome-commander-%s/src directory"), VERSION);
 
             g_free (path2);
         }
@@ -120,7 +120,7 @@ void IMAGE_init ()
 
      // Load file type icons
 
-     for (gint i=0; i<NUM_FILE_TYPE_PIXMAPS; i++)
+     for (size_t i=0; i<NUM_FILE_TYPE_PIXMAPS; i++)
     {
         CacheEntry *e = &file_type_pixmaps[i];
         gchar *path = g_build_filename (PIXMAPS_DIR, file_type_pixmap_files[i], NULL);
@@ -131,10 +131,10 @@ void IMAGE_init ()
         {
             gchar *path2 = g_build_filename ("../pixmaps", pixmap_files[i], NULL);
 
-            g_warning (_("Couldn't load installed pixmap, trying to load %s instead"), path2);
+            g_warning (_("Couldn’t load installed pixmap, trying to load %s instead"), path2);
 
             if (!load_icon (path2, &e->pixmap, &e->mask, &e->lnk_pixmap, &e->lnk_mask))
-                g_warning (_("Can't find the pixmap anywhere. Make sure you have installed the program or is executing gnome-commander from the gnome-commander-%s/src directory"), VERSION);
+                g_warning (_("Can’t find the pixmap anywhere. Make sure you have installed the program or is executing gnome-commander from the gnome-commander-%s/src directory"), VERSION);
             g_free (path2);
         }
 
@@ -189,6 +189,10 @@ static const gchar *get_type_icon_name (GnomeVFSFileType type)
         "i-symlink.png"
     };
 
+#if defined (__GNUC__)
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wswitch-enum"
+#endif
     switch (type)
     {
         case GNOME_VFS_FILE_TYPE_DIRECTORY:
@@ -209,6 +213,9 @@ static const gchar *get_type_icon_name (GnomeVFSFileType type)
         default:
             return names[1];
     }
+#if defined (__GNUC__)
+#pragma GCC diagnostic pop
+#endif
 
     return NULL;
 }
@@ -246,7 +253,7 @@ inline gchar *get_mime_document_type_icon_path (const gchar *mime_type, const gc
  */
 inline gchar *get_category_icon_path (const gchar *mime_type, const gchar *icon_dir)
 {
-    for (gint i=0; i<G_N_ELEMENTS(categories); i++)
+    for (size_t i=0; i<G_N_ELEMENTS(categories); i++)
         if (g_str_has_prefix (mime_type, categories[i][0]))
             return g_build_filename (icon_dir, categories[i][1], NULL);
 
@@ -423,6 +430,10 @@ gboolean IMAGE_get_pixmap_and_mask (GnomeVFSFileType type,
                                     GdkPixmap **pixmap,
                                     GdkBitmap **mask)
 {
+#if defined (__GNUC__)
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wswitch-enum"
+#endif
     switch (gnome_cmd_data.options.layout)
     {
         case GNOME_CMD_LAYOUT_TYPE_ICONS:
@@ -436,6 +447,9 @@ gboolean IMAGE_get_pixmap_and_mask (GnomeVFSFileType type,
         default:
             return FALSE;
     }
+#if defined (__GNUC__)
+#pragma GCC diagnostic pop
+#endif
 
     return FALSE;
 }
