@@ -4,7 +4,7 @@
  * 
  *  @copyright (C) 2006 Assaf Gordon\n
  *  @copyright (C) 2007-2012 Piotr Eljasiak\n
- *  @copyright (C) 2013-2016 Uwe Scholz\n
+ *  @copyright (C) 2013-2017 Uwe Scholz\n
  * 
  *  @copyright This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,9 +22,7 @@
  *
  */
 
-
-#ifndef __GVIEWER_BM_BYTE_H__
-#define __GVIEWER_BM_BYTE_H__
+#pragma once
 
 #include <glib.h>
 #include <glib-object.h>
@@ -47,5 +45,3 @@ struct GViewerBMByteData
 GViewerBMByteData *create_bm_byte_data(const guint8 *pattern, const gint length);
 
 void free_bm_byte_data(GViewerBMByteData *data);
-
-#endif /* __GLIBVIEWER_BM_BYTE_H__ */
