@@ -4,7 +4,7 @@
  *
  * @copyright (C) 2006 Assaf Gordon\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2016 Uwe Scholz\n
+ * @copyright (C) 2013-2017 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,8 +22,7 @@
  *
  */
 
-#ifndef __GVIEWER_BM_CHARTYPE_H__
-#define __GVIEWER_BM_CHARTYPE_H__
+#pragma once
 
 #include <glib.h>
 #include <glib-object.h>
@@ -65,5 +64,3 @@ inline int bm_chartype_get_good_match_advancement(GViewerBMChartypeData *data)
 {
     return data->good[0];
 }
-
-#endif /* __GLIBVIEWER_BM_CHARTYPE_H__ */
