@@ -4,7 +4,7 @@
  *
  * @copyright (C) 2006 Assaf Gordon\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2016 Uwe Scholz\n
+ * @copyright (C) 2013-2017 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,8 +22,7 @@
  *
  */
 
-#ifndef __LIBGVIEWER_TYPES_H__
-#define __LIBGVIEWER_TYPES_H__
+#pragma once
 
 /* TODO: Change these for Big-Endian machines */
 
@@ -48,5 +47,3 @@ typedef guint32  char_type;
 */
 typedef unsigned long offset_type;
 #define INVALID_OFFSET ((offset_type) -1)
-
-#endif // __LIBGVIEWER_TYPES_H__
