@@ -141,13 +141,8 @@ void image_render_set_h_adjustment (ImageRender *obj, GtkAdjustment *adjustment)
     g_signal_connect (adjustment, "value-changed", G_CALLBACK (image_render_h_adjustment_value_changed), obj);
 
     obj->priv->old_h_adj_value = gtk_adjustment_get_value (adjustment);
-#if GTK_CHECK_VERSION (2, 14, 0)
     obj->priv->old_h_adj_lower = gtk_adjustment_get_lower (adjustment);
     obj->priv->old_h_adj_upper = gtk_adjustment_get_upper (adjustment);
-#else
-    obj->priv->old_h_adj_lower = adjustment->lower;
-    obj->priv->old_h_adj_upper = adjustment->upper;
-#endif
 
     image_render_h_adjustment_update (obj);
 }
@@ -170,13 +165,8 @@ void image_render_set_v_adjustment (ImageRender *obj, GtkAdjustment *adjustment)
     g_signal_connect (adjustment, "value-changed",  G_CALLBACK (image_render_v_adjustment_value_changed), obj);
 
     obj->priv->old_v_adj_value = gtk_adjustment_get_value (adjustment);
-#if GTK_CHECK_VERSION (2, 14, 0)
     obj->priv->old_v_adj_lower = gtk_adjustment_get_lower (adjustment);
     obj->priv->old_v_adj_upper = gtk_adjustment_get_upper (adjustment);
-#else
-    obj->priv->old_v_adj_lower = adjustment->lower;
-    obj->priv->old_v_adj_upper = adjustment->upper;
-#endif
 
     image_render_v_adjustment_update (obj);
 }
@@ -332,11 +322,8 @@ static void image_render_realize (GtkWidget *widget)
     gint attributes_mask = GDK_WA_X | GDK_WA_Y | GDK_WA_VISUAL | GDK_WA_COLORMAP;
 
     GdkWindow *window = gdk_window_new (widget->parent->window, &attributes, attributes_mask);
-#if GTK_CHECK_VERSION (2,18,0)
     gtk_widget_set_window (widget, window);
-#else
-    widget->window = window;
-#endif
+
     widget->style = gtk_style_attach (widget->style, window);
     gdk_window_set_user_data (window, widget);
     gtk_style_set_background (widget->style, window, GTK_STATE_ACTIVE);
@@ -353,11 +340,7 @@ static void image_render_redraw (ImageRender *w)
         return;
 
     image_render_notify_status_changed (w);
-#if GTK_CHECK_VERSION (2,14,0)
     gdk_window_invalidate_rect (gtk_widget_get_window (GTK_WIDGET (w)), NULL, FALSE);
-#else
-    gdk_window_invalidate_rect (GTK_WIDGET (w)->window, NULL, FALSE);
-#endif
 }
 
 
@@ -377,11 +360,7 @@ static void image_render_size_allocate (GtkWidget *widget, GtkAllocation *alloca
 
     if (GTK_WIDGET_REALIZED (widget))
     {
-#if GTK_CHECK_VERSION (2,14,0)
         gdk_window_move_resize (gtk_widget_get_window (widget), allocation->x, allocation->y, allocation->width, allocation->height);
-#else
-        gdk_window_move_resize (widget->window, allocation->x, allocation->y, allocation->width, allocation->height);
-#endif
         image_render_prepare_disp_pixbuf (IMAGE_RENDER (widget));
     }
 }
@@ -397,11 +376,7 @@ static gboolean image_render_expose (GtkWidget *widget, GdkEventExpose *event)
 
     ImageRender *w = IMAGE_RENDER (widget);
 
-#if GTK_CHECK_VERSION (2,14,0)
     gdk_window_clear_area (gtk_widget_get_window (widget), 0, 0, widget->allocation.width, widget->allocation.height);
-#else
-    gdk_window_clear_area (widget->window, 0, 0, widget->allocation.width, widget->allocation.height);
-#endif
 
     if (!w->priv->disp_pixbuf)
         return FALSE;
@@ -415,11 +390,7 @@ static gboolean image_render_expose (GtkWidget *widget, GdkEventExpose *event)
         xc = widget->allocation.width / 2 - gdk_pixbuf_get_width (w->priv->disp_pixbuf)/2;
         yc = widget->allocation.height / 2 - gdk_pixbuf_get_height (w->priv->disp_pixbuf)/2;
 
-#if GTK_CHECK_VERSION (2,14,0)
         gdk_draw_pixbuf (gtk_widget_get_window (widget),
-#else
-        gdk_draw_pixbuf (widget->window,
-#endif
                 NULL,
                 w->priv->disp_pixbuf,
                 0, 0, // source X, Y
@@ -477,11 +448,7 @@ static gboolean image_render_expose (GtkWidget *widget, GdkEventExpose *event)
                 (int)w->priv->h_adjustment->value,
                 (int)w->priv->v_adjustment->value);
 #endif
-#if GTK_CHECK_VERSION (2,14,0)
         gdk_draw_pixbuf(gtk_widget_get_window (widget),
-#else
-        gdk_draw_pixbuf(widget->window,
-#endif
                         NULL,
                         w->priv->disp_pixbuf,
                         src_x, src_y,
@@ -549,15 +516,10 @@ static gboolean image_render_motion_notify (GtkWidget *widget, GdkEventMotion *e
         gint x = event->x;
         gint y = event->y;
 
-#if GTK_CHECK_VERSION (2,14,0)
         GdkWindow *window = gtk_widget_get_window (widget);
 
         if (event->is_hint || (event->window != window))
             gdk_window_get_pointer (window, &x, &y, &mods);
-#else
-        if (event->is_hint || (event->window != widget->window))
-            gdk_window_get_pointer (widget->window, &x, &y, &mods);
-#endif
         // TODO: respond to motion event
     }
 
@@ -571,19 +533,11 @@ static void image_render_h_adjustment_update (ImageRender *obj)
 
     gfloat new_value = gtk_adjustment_get_value (obj->priv->h_adjustment);
 
-#if GTK_CHECK_VERSION (2,14,0)
     if (new_value < gtk_adjustment_get_lower (obj->priv->h_adjustment))
         new_value = gtk_adjustment_get_lower (obj->priv->h_adjustment);
 
     if (new_value > gtk_adjustment_get_upper (obj->priv->h_adjustment))
         new_value = gtk_adjustment_get_upper (obj->priv->h_adjustment);
-#else
-    if (new_value < obj->priv->h_adjustment->lower)
-        new_value = obj->priv->h_adjustment->lower;
-
-    if (new_value > obj->priv->h_adjustment->upper)
-        new_value = obj->priv->h_adjustment->upper;
-#endif
 
     if (new_value != gtk_adjustment_get_value (obj->priv->h_adjustment))
     {
@@ -605,7 +559,6 @@ static void image_render_h_adjustment_changed (GtkAdjustment *adjustment, gpoint
 
     ImageRender *obj = IMAGE_RENDER (data);
 
-#if GTK_CHECK_VERSION (2,14,0)
     if ((obj->priv->old_h_adj_value != gtk_adjustment_get_value (adjustment)) ||
         (obj->priv->old_h_adj_lower != gtk_adjustment_get_lower (adjustment)) ||
         (obj->priv->old_h_adj_upper != gtk_adjustment_get_upper (adjustment)))
@@ -616,18 +569,6 @@ static void image_render_h_adjustment_changed (GtkAdjustment *adjustment, gpoint
         obj->priv->old_h_adj_lower = gtk_adjustment_get_lower (adjustment);
         obj->priv->old_h_adj_upper = gtk_adjustment_get_upper (adjustment);
     }
-#else
-    if ((obj->priv->old_h_adj_value != adjustment->value) ||
-        (obj->priv->old_h_adj_lower != adjustment->lower) ||
-        (obj->priv->old_h_adj_upper != adjustment->upper))
-    {
-        image_render_h_adjustment_update (obj);
-
-        obj->priv->old_h_adj_value = adjustment->value;
-        obj->priv->old_h_adj_lower = adjustment->lower;
-        obj->priv->old_h_adj_upper = adjustment->upper;
-    }
-#endif
 }
 
 
@@ -652,19 +593,11 @@ static void image_render_v_adjustment_update (ImageRender *obj)
 
     gfloat new_value = gtk_adjustment_get_value (obj->priv->v_adjustment);
 
-#if GTK_CHECK_VERSION (2,14,0)
     if (new_value < gtk_adjustment_get_lower (obj->priv->v_adjustment))
         new_value = gtk_adjustment_get_lower (obj->priv->v_adjustment);
 
     if (new_value > gtk_adjustment_get_upper (obj->priv->v_adjustment))
         new_value = gtk_adjustment_get_upper (obj->priv->v_adjustment);
-#else
-    if (new_value < obj->priv->v_adjustment->lower)
-        new_value = obj->priv->v_adjustment->lower;
-
-    if (new_value > obj->priv->v_adjustment->upper)
-        new_value = obj->priv->v_adjustment->upper;
-#endif
 
     if (new_value != gtk_adjustment_get_value (obj->priv->v_adjustment))
     {
@@ -686,7 +619,6 @@ static void image_render_v_adjustment_changed (GtkAdjustment *adjustment, gpoint
 
     ImageRender *obj = IMAGE_RENDER (data);
 
-#if GTK_CHECK_VERSION (2,14,0)
     if ((obj->priv->old_v_adj_value != gtk_adjustment_get_value (adjustment)) ||
         (obj->priv->old_v_adj_lower != gtk_adjustment_get_lower (adjustment)) ||
         (obj->priv->old_v_adj_upper != gtk_adjustment_get_upper (adjustment)))
@@ -697,18 +629,6 @@ static void image_render_v_adjustment_changed (GtkAdjustment *adjustment, gpoint
         obj->priv->old_v_adj_lower = gtk_adjustment_get_lower (adjustment);
         obj->priv->old_v_adj_upper = gtk_adjustment_get_upper (adjustment);
     }
-#else
-    if ((obj->priv->old_v_adj_value != adjustment->value) ||
-        (obj->priv->old_v_adj_lower != adjustment->lower) ||
-        (obj->priv->old_v_adj_upper != adjustment->upper))
-    {
-        image_render_v_adjustment_update (obj);
-
-        obj->priv->old_v_adj_value = adjustment->value;
-        obj->priv->old_v_adj_lower = adjustment->lower;
-        obj->priv->old_v_adj_upper = adjustment->upper;
-    }
-#endif
 }
 
 
@@ -826,7 +746,7 @@ inline void image_render_start_background_pixbuf_loading (ImageRender *obj)
 
     // Start background loading
     g_object_ref (obj);
-    obj->priv->pixbuf_loading_thread = g_thread_create((GThreadFunc) image_render_pixbuf_loading_thread, (gpointer) obj, FALSE, NULL);
+    obj->priv->pixbuf_loading_thread = g_thread_new("pixbuf_load", (GThreadFunc) image_render_pixbuf_loading_thread, (gpointer) obj);
 }
 
 
@@ -922,25 +842,15 @@ static void image_render_update_adjustments (ImageRender *obj)
     {
         if (obj->priv->h_adjustment)
         {
-#if GTK_CHECK_VERSION (2,14,0)
             gtk_adjustment_set_lower (obj->priv->h_adjustment, 0);
             gtk_adjustment_set_upper (obj->priv->h_adjustment, 0);
-#else
-            obj->priv->h_adjustment->lower = 0;
-            obj->priv->h_adjustment->upper = 0;
-#endif
             gtk_adjustment_set_value (obj->priv->h_adjustment, 0);
             gtk_adjustment_changed (obj->priv->h_adjustment);
         }
         if (obj->priv->v_adjustment)
         {
-#if GTK_CHECK_VERSION (2,14,0)
             gtk_adjustment_set_lower (obj->priv->v_adjustment, 0);
             gtk_adjustment_set_upper (obj->priv->v_adjustment, 0);
-#else
-            obj->priv->v_adjustment->lower = 0;
-            obj->priv->v_adjustment->upper = 0;
-#endif
             gtk_adjustment_set_value (obj->priv->v_adjustment, 0);
             gtk_adjustment_changed (obj->priv->v_adjustment);
         }
@@ -949,28 +859,16 @@ static void image_render_update_adjustments (ImageRender *obj)
     {
         if (obj->priv->h_adjustment)
         {
-#if GTK_CHECK_VERSION (2,14,0)
             gtk_adjustment_set_lower (obj->priv->h_adjustment, 0);
             gtk_adjustment_set_upper (obj->priv->h_adjustment, gdk_pixbuf_get_width (obj->priv->disp_pixbuf));
             gtk_adjustment_set_page_size (obj->priv->h_adjustment, GTK_WIDGET (obj)->allocation.width);
-#else
-            obj->priv->h_adjustment->lower = 0;
-            obj->priv->h_adjustment->upper = gdk_pixbuf_get_width (obj->priv->disp_pixbuf);
-            obj->priv->h_adjustment->page_size = GTK_WIDGET (obj)->allocation.width;
-#endif
             gtk_adjustment_changed (obj->priv->h_adjustment);
         }
         if (obj->priv->v_adjustment)
         {
-#if GTK_CHECK_VERSION (2,14,0)
             gtk_adjustment_set_lower (obj->priv->v_adjustment, 0);
             gtk_adjustment_set_upper (obj->priv->v_adjustment, gdk_pixbuf_get_height (obj->priv->disp_pixbuf));
             gtk_adjustment_set_page_size (obj->priv->v_adjustment, GTK_WIDGET (obj)->allocation.height);
-#else
-            obj->priv->v_adjustment->lower = 0;
-            obj->priv->v_adjustment->upper = gdk_pixbuf_get_height (obj->priv->disp_pixbuf);
-            obj->priv->v_adjustment->page_size = GTK_WIDGET (obj)->allocation.height;
-#endif
             gtk_adjustment_changed (obj->priv->v_adjustment);
         }
     }
