@@ -4,7 +4,7 @@
  *
  * @copyright (C) 2006 Assaf Gordon\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2016 Uwe Scholz\n
+ * @copyright (C) 2013-2017 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,8 +22,7 @@
  *
  */
 
-#ifndef __LIBGVIEWER_INPUT_MODES_H__
-#define __LIBGVIEWER_INPUT_MODES_H__
+#pragma once
 
 #define is_displayable(c) (((c) >= 0x20) && ((c) < 0x7f))
 
@@ -123,5 +122,3 @@ offset_type gv_input_get_next_char_offset(GVInputModesData *imd, offset_type cur
 
 */
 offset_type gv_input_get_previous_char_offset(GVInputModesData *imd, offset_type current_offset);
-
-#endif // __LIBGVIEWER_INPUT_MODES_H__
