@@ -4,7 +4,7 @@
  *
  * @copyright (C) 2006 Assaf Gordon\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2016 Uwe Scholz\n
+ * @copyright (C) 2013-2017 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,8 +22,7 @@
  *
  */
 
-#ifndef __LIB_GVIEWER_H__
-#define __LIB_GVIEWER_H__
+#pragma once
 
 #include <gtk/gtk.h>
 #include <gtk/gtkadjustment.h>
@@ -42,5 +41,3 @@
 #include "search-dlg.h"
 #include "searcher.h"
 #include "search-progress-dlg.h"
-
-#endif
