@@ -4,7 +4,7 @@
  *
  * @copyright (C) 2006 Assaf Gordon\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2016 Uwe Scholz\n
+ * @copyright (C) 2013-2017 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,8 +22,7 @@
  *
  */
 
-#ifndef __LIBGVIEWER_SEARCH_DLG_H__
-#define __LIBGVIEWER_SEARCH_DLG_H__
+#pragma once
 
 #define GVIEWER_SEARCH_DLG(obj)          GTK_CHECK_CAST (obj, gviewer_search_dlg_get_type(), GViewerSearchDlg)
 #define GVIEWER_SEARCH_DLG_CLASS(klass)  GTK_CHECK_CLASS_CAST (klass, gviewer_search_dlg_get_type(), GViewerSearchDlgClass)
@@ -63,5 +62,3 @@ guint8 *gviewer_search_dlg_get_search_hex_buffer (GViewerSearchDlg *sdlg, /*out*
 gboolean gviewer_search_dlg_get_case_sensitive (GViewerSearchDlg *sdlg);
 
 void gviewer_show_search_dlg (GtkWindow *parent);
-
-#endif /* __LIBGVIEWER_SEARCH_DLG_H__ */
