@@ -4,7 +4,7 @@
  *
  * @copyright (C) 2006 Assaf Gordon\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2016 Uwe Scholz\n
+ * @copyright (C) 2013-2017 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -301,7 +301,7 @@ void g_viewer_searcher_setup_new_hex_search(GViewerSearcher *srchr,
 }
 
 
-void update_progress_indicator (GViewerSearcher *src, offset_type pos)
+static void update_progress_indicator (GViewerSearcher *src, offset_type pos)
 {
     gdouble d = (pos*1000.0) / src->priv->max_offset;
 
@@ -312,13 +312,13 @@ void update_progress_indicator (GViewerSearcher *src, offset_type pos)
 }
 
 
-gboolean check_abort_request (GViewerSearcher *src)
+static gboolean check_abort_request (GViewerSearcher *src)
 {
     return g_atomic_int_get (&src->priv->abort_indicator)!=0;
 }
 
 
-gboolean search_hex_forward (GViewerSearcher *src)
+static gboolean search_hex_forward (GViewerSearcher *src)
 {
     offset_type m, n, j;
     int i;
@@ -348,7 +348,7 @@ gboolean search_hex_forward (GViewerSearcher *src)
             break;
         }
 
-        j += MAX(data->good[i], data->bad[value] - m + 1 + i);
+        j += MAX((offset_type)data->good[i], data->bad[value] - m + 1 + i);
 
         if (--update_counter==0)
         {
@@ -368,9 +368,9 @@ gboolean search_hex_forward (GViewerSearcher *src)
 }
 
 
-gboolean search_hex_backward (GViewerSearcher *src)
+static gboolean search_hex_backward (GViewerSearcher *src)
 {
-    offset_type m, n, j;
+    offset_type m, j;
     int i;
     gboolean found = FALSE;
     int update_counter;
@@ -380,7 +380,6 @@ gboolean search_hex_backward (GViewerSearcher *src)
     data = src->priv->b_reverse_data;
 
     m = data->pattern_len;
-    n = src->priv->max_offset;
     j = src->priv->start_offset;
     update_counter = src->priv->update_interval;
 
@@ -402,7 +401,7 @@ gboolean search_hex_backward (GViewerSearcher *src)
             break;
         }
 
-        j -= MAX(data->good[i], data->bad[value] - m + 1 + i);
+        j -= MAX((offset_type)data->good[i], data->bad[value] - m + 1 + i);
 
         if (--update_counter==0)
         {
@@ -422,9 +421,9 @@ gboolean search_hex_backward (GViewerSearcher *src)
 }
 
 
-gboolean search_text_forward (GViewerSearcher *src)
+static gboolean search_text_forward (GViewerSearcher *src)
 {
-    offset_type m, n, j, t, delta;
+    offset_type m, n, j;
     int i;
     gboolean found = FALSE;
     char_type value;
@@ -437,6 +436,8 @@ gboolean search_text_forward (GViewerSearcher *src)
 
     while (j <= n - m)
     {
+        offset_type t, delta;
+
         delta = m - 1;
         t = j;
         while (delta--)
@@ -484,9 +485,9 @@ gboolean search_text_forward (GViewerSearcher *src)
 }
 
 
-gboolean search_text_backward (GViewerSearcher *src)
+static gboolean search_text_backward (GViewerSearcher *src)
 {
-    offset_type m, n, j, t, delta;
+    offset_type m, j;
     int i;
     gboolean found = FALSE;
     int update_counter;
@@ -496,7 +497,6 @@ gboolean search_text_backward (GViewerSearcher *src)
     data = src->priv->ct_reverse_data;
 
     m = data->pattern_len;
-    n = src->priv->max_offset;
     j = src->priv->start_offset;
 
     update_counter = src->priv->update_interval;
@@ -504,6 +504,8 @@ gboolean search_text_backward (GViewerSearcher *src)
     j = gv_input_get_previous_char_offset(src->priv->imd, j);
     while (j >= m)
     {
+        offset_type t, delta;
+
         delta = m - 1;
         t = j;
         while (delta--)
@@ -548,7 +550,7 @@ gboolean search_text_backward (GViewerSearcher *src)
 }
 
 
-gpointer search_func (gpointer user_data)
+static gpointer search_func (gpointer user_data)
 {
     g_return_val_if_fail (G_IS_VIEWERSEARCHER(user_data), NULL);
 
@@ -598,6 +600,6 @@ void g_viewer_searcher_start_search(GViewerSearcher *src, gboolean forward)
 
     src->priv->search_forward = forward;
 
-    src->priv->search_thread = g_thread_create (search_func, (gpointer) src, TRUE, NULL);
+    src->priv->search_thread = g_thread_new (NULL, search_func, (gpointer) src);
     g_return_if_fail (src->priv->search_thread!=NULL);
 }
