@@ -4,7 +4,7 @@
  *
  * @copyright (C) 2006 Assaf Gordon\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2016 Uwe Scholz\n
+ * @copyright (C) 2013-2017 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,8 +22,7 @@
  *
  */
 
-#ifndef SEARCHER_H
-#define SEARCHER_H
+#pragma once
 
 #include <glib.h>
 #include <glib-object.h>
@@ -122,5 +121,3 @@ gint * g_viewer_searcher_get_abort_indicator(GViewerSearcher *src);
    (read glib's "atomic operations").
    */
 gint * g_viewer_searcher_get_complete_indicator(GViewerSearcher *src);
-
-#endif /* SEARCHER_H */
