@@ -4,7 +4,7 @@
  *
  * @copyright (C) 2006 Assaf Gordon\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2016 Uwe Scholz\n
+ * @copyright (C) 2013-2017 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,8 +22,7 @@
  *
  */
 
-#ifndef __LIBGVIEWER_UTILS_H__
-#define __LIBGVIEWER_UTILS_H__
+#pragma once
 
 #define GVIEWER_DEFAULT_PATH_PREFIX "/gnome-commander/internal_viewer/"
 
@@ -42,5 +41,3 @@ inline char_type chartype_toupper(char_type ch)
 }
 
 #define CHARTYPE_CASE(ch,casesens) ((casesens)?ch:chartype_toupper(ch))
-
-#endif
