@@ -2,7 +2,7 @@
  * @file ls_colors.h
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2016 Uwe Scholz\n
+ * @copyright (C) 2013-2017 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,8 +19,7 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-#ifndef __LS_COLORS_H__
-#define __LS_COLORS_H__
+#pragma once
 
 #include "gnome-cmd-file.h"
 
@@ -33,5 +32,3 @@ struct LsColor
 
 void     ls_colors_init ();
 LsColor *ls_colors_get (GnomeCmdFile *f);
-
-#endif // __LS_COLORS_H__
