@@ -2,7 +2,7 @@
  * @file utils.cc
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2016 Uwe Scholz\n
+ * @copyright (C) 2013-2017 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,7 +20,6 @@
  */
 
 #include <config.h>
-#include <locale.h>
 #include <errno.h>
 #include <dirent.h>
 #include <fnmatch.h>
@@ -31,26 +30,12 @@
 #include "gnome-cmd-includes.h"
 #include "utils.h"
 #include "gnome-cmd-data.h"
-#include "gnome-cmd-plain-path.h"
 #include "imageloader.h"
 #include "gnome-cmd-main-win.h"
-#include "gnome-cmd-con-list.h"
-#include "gnome-cmd-xfer.h"
 
 using namespace std;
 
 
-struct TmpDlData
-{
-    GnomeCmdFile *f;
-    GtkWidget *dialog;
-    gpointer *args;
-};
-
-#ifdef HAVE_LOCALE_H
-extern struct lconv *locale_information;
-#endif
-
 #define FIX_PW_HACK
 #define STRINGS_TO_URIS_CHUNK 1024
 
@@ -104,6 +89,9 @@ void DEBUG (gchar flag, const gchar *format, ...)
  */
 void run_command_indir (const gchar *in_command, const gchar *dpath, gboolean term)
 {
+    g_return_if_fail (in_command != NULL);
+    g_return_if_fail (strlen(in_command) != 0);
+
     gchar *command;
 
     if (term)
@@ -119,7 +107,14 @@ void run_command_indir (const gchar *in_command, const gchar *dpath, gboolean te
         else
             arg = g_shell_quote (in_command);
 
+#if defined (__GNUC__)
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wformat-nonliteral"
+#endif
         command = g_strdup_printf (gnome_cmd_data.options.termexec, arg);
+#if defined (__GNUC__)
+#pragma GCC diagnostic pop
+#endif
 
         g_free (arg);
     }
@@ -127,7 +122,7 @@ void run_command_indir (const gchar *in_command, const gchar *dpath, gboolean te
         command = g_strdup (in_command);
 
     DEBUG ('g', "running%s: %s\n", (term?" in terminal":""), command);
- 
+
     gint argc;
     gchar **argv;
     GError *error = NULL;
@@ -234,25 +229,6 @@ gint run_simple_dialog (GtkWidget *parent, gboolean ignore_close_box,
     return result;
 }
 
-gchar *str_uri_basename (const gchar *uri)
-{
-    if (!uri)
-        return NULL;
-
-    int len = strlen (uri),
-        last_slash=0;
-
-    if (len < 2)
-        return NULL;
-
-    for (int i=0; i<len; i++)
-        if (uri[i] == '/')
-            last_slash = i;
-
-    return gnome_vfs_unescape_string (&uri[last_slash+1], NULL);
-}
-
-
 const gchar *type2string (GnomeVFSFileType type, gchar *buf, guint max)
 {
     const char *s;
@@ -375,18 +351,18 @@ const gchar *size2string (GnomeVFSFileSize size, GnomeCmdSizeDispMode size_disp_
                 if (i)
                     g_snprintf (buf0, sizeof(buf0), "%.1f %s ", dsize, prefixes[i]);
                 else
-                    g_snprintf (buf0, sizeof(buf0), "%llu %s ", size, prefixes[0]);
+                    g_snprintf (buf0, sizeof(buf0), "%" GNOME_VFS_SIZE_FORMAT_STR " %s ", size, prefixes[0]);
             }
             break;
 
         case GNOME_CMD_SIZE_DISP_MODE_GROUPED:
             {
-                gint len = g_snprintf (buf0, sizeof(buf0), "%llu ", size);
+                gint len = g_snprintf (buf0, sizeof(buf0), "%" GNOME_VFS_SIZE_FORMAT_STR " ", size);
 
                 if (len < 5)
                     return buf0;
 
-                gchar *sep = " ";
+                gchar *sep = (gchar*) " ";
 
                 gchar *src  = buf0;
                 gchar *dest = buf1;
@@ -404,11 +380,14 @@ const gchar *size2string (GnomeVFSFileSize size, GnomeCmdSizeDispMode size_disp_
             return buf1;
 
         case GNOME_CMD_SIZE_DISP_MODE_LOCALE:
-            g_snprintf (buf0, sizeof(buf0), "%'llu ", size);
+            g_snprintf (buf0, sizeof(buf0), "%'" GNOME_VFS_SIZE_FORMAT_STR " ", size);
             break;
 
         case GNOME_CMD_SIZE_DISP_MODE_PLAIN:
-            g_snprintf (buf0, sizeof(buf0), "%llu ", size);
+            g_snprintf (buf0, sizeof(buf0), "%" GNOME_VFS_SIZE_FORMAT_STR " ", size);
+            break;
+
+        default:
             break;
     }
 
@@ -424,7 +403,14 @@ const gchar *time2string (time_t t, const gchar *date_format)
     struct tm lt;
 
     localtime_r (&t, &lt);
+#if defined (__GNUC__)
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wformat-nonliteral"
+#endif
     strftime (buf, sizeof(buf), date_format, &lt);
+#if defined (__GNUC__)
+#pragma GCC diagnostic pop
+#endif
 
     // convert formatted date from current locale to UTF8
     gchar *loc_date = g_locale_to_utf8 (buf, -1, NULL, NULL, NULL);
@@ -437,284 +423,6 @@ const gchar *time2string (time_t t, const gchar *date_format)
 }
 
 
-inline void no_mime_app_found_error (gchar *mime_type)
-{
-    gchar *msg = g_strdup_printf (_("No default application found for the MIME type %s."), mime_type);
-    gnome_cmd_show_message (NULL, msg, "Open the \"File types and programs\" page in the Control Center to add one.");
-    g_free (msg);
-}
-
-
-static void do_mime_exec_single (gpointer *args)
-{
-    g_return_if_fail (args != NULL);
-
-    GnomeCmdApp *app = (GnomeCmdApp *) args[0];
-    gchar *path = (gchar *) args[1];
-    gchar *dpath = (gchar *) args[2];
-
-    string cmd = gnome_cmd_app_get_command (app);
-    cmd += ' ';
-    cmd += stringify (g_shell_quote (path));
-
-    run_command_indir (cmd.c_str(), dpath, gnome_cmd_app_get_requires_terminal (app));
-
-    g_free (path);
-    g_free (dpath);
-    gnome_cmd_app_free (app);
-    g_free (args);
-}
-
-
-static void on_tmp_download_response (GtkWidget *w, gint id, TmpDlData *dldata)
-{
-    if (id == GTK_RESPONSE_YES)
-    {
-        gchar *path_str = get_temp_download_filepath (dldata->f->get_name());
-
-        if (!path_str) return;
-
-        dldata->args[1] = (gpointer) path_str;
-
-        GnomeVFSURI *src_uri = gnome_vfs_uri_dup (dldata->f->get_uri());
-        GnomeCmdPlainPath path(path_str);
-        GnomeVFSURI *dest_uri = gnome_cmd_con_create_uri (get_home_con (), &path);
-
-        gnome_cmd_xfer_tmp_download (src_uri,
-                                     dest_uri,
-                                     GNOME_VFS_XFER_FOLLOW_LINKS,
-                                     GNOME_VFS_XFER_OVERWRITE_MODE_REPLACE,
-                                     GTK_SIGNAL_FUNC (do_mime_exec_single),
-                                     dldata->args);
-    }
-    else
-    {
-        gnome_cmd_app_free ((GnomeCmdApp *) dldata->args[0]);
-        g_free (dldata->args);
-    }
-
-    g_free (dldata);
-    gtk_widget_destroy (dldata->dialog);
-}
-
-
-void mime_exec_single (GnomeCmdFile *f)
-{
-    g_return_if_fail (f != NULL);
-    g_return_if_fail (f->info != NULL);
-
-    gpointer *args;
-    GnomeVFSMimeApplication *vfs_app;
-    GnomeCmdApp *app;
-
-    if (!f->info->mime_type)
-        return;
-
-    // Check if the file is a binary executable that lacks the executable bit
-
-    if (!f->is_executable())
-    {
-        if (f->has_mime_type("application/x-executable") || f->has_mime_type("application/x-executable-binary"))
-        {
-            gchar *fname = get_utf8 (f->info->name);
-            gchar *msg = g_strdup_printf (_("\"%s\" seems to be a binary executable file but it lacks the executable bit. Do you want to set it and then run the file?"), fname);
-            gint ret = run_simple_dialog (*main_win, FALSE, GTK_MESSAGE_QUESTION, msg,
-                                          _("Make Executable?"),
-                                          -1, _("Cancel"), _("OK"), NULL);
-            g_free (fname);
-            g_free (msg);
-
-            if (ret != 1)  return;  else
-            {
-                GnomeVFSResult result = f->chmod((GnomeVFSFilePermissions) (f->info->permissions|GNOME_VFS_PERM_USER_EXEC));
-                if (result != GNOME_VFS_OK)
-                    return;
-            }
-        }
-    }
-
-    // If the file is executable but not a binary file, check if the user wants to exec it or open it
-
-    if (f->is_executable())
-    {
-        if (f->has_mime_type("application/x-executable") || f->has_mime_type("application/x-executable-binary"))
-        {
-            f->execute();
-            return;
-        }
-        else
-            if (f->mime_begins_with("text/"))
-            {
-                gchar *fname = get_utf8 (f->info->name);
-                gchar *msg = g_strdup_printf (_("\"%s\" is an executable text file. Do you want to run it, or display its contents?"), fname);
-                gint ret = run_simple_dialog (*main_win, FALSE, GTK_MESSAGE_QUESTION, msg, _("Run or Display"),
-                                              -1, _("Cancel"), _("Display"), _("Run"), NULL);
-                g_free (fname);
-                g_free (msg);
-
-                if (ret != 1)
-                {
-                    if (ret == 2)
-                        f->execute();
-                    return;
-                }
-            }
-    }
-
-    vfs_app = gnome_vfs_mime_get_default_application (f->info->mime_type);
-    if (!vfs_app)
-    {
-        no_mime_app_found_error (f->info->mime_type);
-        return;
-    }
-
-    app = gnome_cmd_app_new_from_vfs_app (vfs_app);
-    gnome_vfs_mime_application_free (vfs_app);
-
-    args = g_new0 (gpointer, 3);
-
-    if (f->is_local())
-    {
-        args[0] = (gpointer) app;
-        args[1] = (gpointer) f->get_real_path();
-        args[2] = (gpointer) g_path_get_dirname ((gchar *) args[1]);            // set exec dir for local files
-        do_mime_exec_single (args);
-    }
-    else
-    {
-        if (gnome_cmd_app_get_handles_uris (app) && gnome_cmd_data.options.honor_expect_uris)
-        {
-            args[0] = (gpointer) app;
-            args[1] = (gpointer) f->get_uri_str();
-            // args[2] is NULL here (don't set exec dir for remote files)
-            do_mime_exec_single (args);
-        }
-        else
-        {
-            gchar *msg = g_strdup_printf (_("%s does not know how to open remote file. Do you want to download the file to a temporary location and then open it?"), gnome_cmd_app_get_name (app));
-            GtkWidget *dialog = gtk_message_dialog_new (*main_win, GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, "%s", msg);
-            TmpDlData *dldata = g_new0 (TmpDlData, 1);
-            args[0] = (gpointer) app;
-            // args[2] is NULL here (don't set exec dir for temporarily downloaded files)
-            dldata->f = f;
-            dldata->dialog = dialog;
-            dldata->args = args;
-
-            g_signal_connect (dialog, "response", G_CALLBACK (on_tmp_download_response), dldata);
-            gtk_widget_show (dialog);
-            g_free (msg);
-        }
-    }
-}
-
-
-static void do_mime_exec_multiple (gpointer *args)
-{
-    GnomeCmdApp *app = (GnomeCmdApp *) args[0];
-    GList *files = (GList *) args[1];
-
-    if (files)
-    {
-        string cmd = gnome_cmd_app_get_command (app);
-
-        set<string> dirs;
-
-        for (; files; files = files->next)
-        {
-            cmd += ' ';
-            cmd += stringify (g_shell_quote ((gchar *) files->data));
-
-            gchar *dpath = g_path_get_dirname ((gchar *) files->data);
-
-            if (dpath)
-                dirs.insert (stringify (dpath));
-        }
-
-        if (dirs.size()==1)
-            run_command_indir (cmd.c_str(), dirs.begin()->c_str(), gnome_cmd_app_get_requires_terminal (app));
-        else
-            run_command_indir (cmd.c_str(), NULL, gnome_cmd_app_get_requires_terminal (app));
-
-        g_list_free (files);
-    }
-
-    gnome_cmd_app_free (app);
-    g_free (args);
-}
-
-
-void mime_exec_multiple (GList *files, GnomeCmdApp *app)
-{
-    g_return_if_fail (files != NULL);
-    g_return_if_fail (app != NULL);
-
-    GList *src_uri_list = NULL;
-    GList *dest_uri_list = NULL;
-    GList *local_files = NULL;
-    gboolean asked = FALSE;
-    guint no_of_remote_files = 0;
-    gint retid;
-
-    for (; files; files = files->next)
-    {
-        GnomeCmdFile *f = (GnomeCmdFile *) files->data;
-
-        if (gnome_vfs_uri_is_local (f->get_uri()))
-            local_files = g_list_append (local_files, f->get_real_path());
-        else
-        {
-            ++no_of_remote_files;
-            if (gnome_cmd_app_get_handles_uris (app) && gnome_cmd_data.options.honor_expect_uris)
-            {
-                local_files = g_list_append (local_files,  f->get_uri_str());
-            }
-            else
-            {
-                if (!asked)
-                {
-                    gchar *msg = g_strdup_printf (ngettext("%s does not know how to open remote file. Do you want to download the file to a temporary location and then open it?",
-                                                           "%s does not know how to open remote files. Do you want to download the files to a temporary location and then open them?", no_of_remote_files),
-                                                  gnome_cmd_app_get_name (app));
-                    retid = run_simple_dialog (*main_win, TRUE, GTK_MESSAGE_QUESTION, msg, "", -1, _("No"), _("Yes"), NULL);
-                    asked = TRUE;
-                }
-
-                if (retid==1)
-                {
-                    gchar *path_str = get_temp_download_filepath (f->get_name());
-
-                    if (!path_str) return;
-
-                    GnomeVFSURI *src_uri = gnome_vfs_uri_dup (f->get_uri());
-                    GnomeCmdPlainPath path(path_str);
-                    GnomeVFSURI *dest_uri = gnome_cmd_con_create_uri (get_home_con (), &path);
-
-                    src_uri_list = g_list_append (src_uri_list, src_uri);
-                    dest_uri_list = g_list_append (dest_uri_list, dest_uri);
-                    local_files = g_list_append (local_files, path_str);
-                }
-            }
-        }
-    }
-
-    g_list_free (files);
-
-    gpointer *args = g_new0 (gpointer, 2);
-    args[0] = app;
-    args[1] = local_files;
-
-    if (src_uri_list)
-        gnome_cmd_xfer_tmp_download_multiple (src_uri_list,
-                                              dest_uri_list,
-                                              GNOME_VFS_XFER_FOLLOW_LINKS,
-                                              GNOME_VFS_XFER_OVERWRITE_MODE_REPLACE,
-                                              GTK_SIGNAL_FUNC (do_mime_exec_multiple),
-                                              args);
-    else
-        do_mime_exec_multiple (args);
-}
-
-
 void clear_event_key (GdkEventKey *event)
 {
     g_return_if_fail (event != NULL);
@@ -1034,8 +742,13 @@ gchar *get_temp_download_filepath (const gchar *fname)
 
     if (!tmp_file_dir)
     {
+        if (chdir (tmp_dir))
+        {
+            gnome_cmd_show_message (NULL, _("Failed to change working directory to a temporary directory."), strerror (errno));
+
+            return NULL;
+        }
         gchar *tmp_file_dir_template = g_strdup_printf ("gcmd-%s-XXXXXX", g_get_user_name());
-        chdir (tmp_dir);
         tmp_file_dir = mkdtemp (tmp_file_dir_template);
         if (!tmp_file_dir)
         {
@@ -1058,7 +771,11 @@ void remove_temp_download_dir ()
         gchar *path = g_build_filename (g_get_tmp_dir (), tmp_file_dir, NULL);
         gchar *command = g_strdup_printf ("rm -rf %s", path);
         g_free (path);
-        system (command);
+        int status;
+        if ((status = system (command)))
+        {
+            g_warning ("executing \"%s\" failed with exit status %d\n", command, status);
+        }
         g_free (command);
     }
 }
@@ -1235,7 +952,7 @@ gboolean create_dir_if_needed (const gchar *dpath)
     {
         if (errno == ENOENT)
         {
-            g_print (_("Creating directory %s... "), dpath);
+            g_print (_("Creating directory %s… "), dpath);
             if (mkdir (dpath, S_IRUSR|S_IWUSR|S_IXUSR) == 0)  return TRUE;  else
             {
                 gchar *msg = g_strdup_printf (_("Failed to create the directory %s"), dpath);
@@ -1244,7 +961,7 @@ gboolean create_dir_if_needed (const gchar *dpath)
             }
         }
         else
-            g_warning (_("Couldn't read from the directory %s: %s"), dpath, strerror (errno));
+            g_warning (_("Couldn’t read from the directory %s: %s"), dpath, strerror (errno));
 
         return FALSE;
     }
@@ -1365,6 +1082,26 @@ void gnome_cmd_toggle_file_name_selection (GtkWidget *entry)
 }
 
 
+void gnome_cmd_help_display (const gchar *file_name, const gchar *link_id)
+{
+    GError *error = NULL;
+    gchar help_uri[256] = "help:";
+
+    strcat(help_uri, PACKAGE_NAME);
+
+    if (link_id != NULL)
+    {
+        strcat(help_uri, "/");
+        strcat(help_uri, link_id);
+    }
+
+    gtk_show_uri (NULL, help_uri,  gtk_get_current_event_time (), &error);
+
+    if (error != NULL)
+        gnome_cmd_error_message (_("There was an error displaying help."), error);
+}
+
+
 gboolean gnome_cmd_prepend_su_to_vector (int &argc, char **&argv)
 {
     // sanity
@@ -1420,7 +1157,6 @@ gboolean gnome_cmd_prepend_su_to_vector (int &argc, char **&argv)
     return TRUE;
 }
 
-
 int split(const string &s, vector<string> &coll, const char *sep)
 {
   coll.clear();
@@ -1441,7 +1177,7 @@ int split(const string &s, vector<string> &coll, const char *sep)
   int n = 1;
   int start = 0;
 
-  for (int end; (end=s.find(sep,start))!=string::npos; ++n)
+  for (int end; (size_t)(end=s.find(sep,start))!=string::npos; ++n)
   {
     coll.push_back(string(s,start,end-start));
     start = end + seplen;
