@@ -18,8 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  */
-#ifndef __UTILS_H__
-#define __UTILS_H__
+#pragma once
 
 #include <string>
 #include <vector>
@@ -28,12 +27,13 @@
 
 #include <stdio.h>
 
-#include <libgnome/gnome-help.h>
+#include <config.h>
 
 #include "gnome-cmd-file.h"
 #include "gnome-cmd-types.h"
 #include "gnome-cmd-pixmap.h"
 #include "gnome-cmd-app.h"
+#include "utils-no-dependencies.h"
 
 #define TRACE(s)  std::cout << __FILE__ "(" << __LINE__ << ") " << __PRETTY_FUNCTION__ << "\t" #s ": `" << (s) << "'" << std::endl
 
@@ -118,8 +118,6 @@ inline char *int2string (gint i)
     return g_strdup_printf ("%d", i);
 }
 
-gchar *str_uri_basename (const gchar *uri);
-
 const gchar *type2string (GnomeVFSFileType type, gchar *buf, guint max);
 const gchar *name2string (gchar *filename, gchar *buf, guint max);
 const gchar *perm2string (GnomeVFSFilePermissions p, gchar *buf, guint max);
@@ -128,9 +126,6 @@ const gchar *perm2numstring (GnomeVFSFilePermissions p, gchar *buf, guint max);
 const gchar *size2string (GnomeVFSFileSize size, GnomeCmdSizeDispMode size_disp_mode);
 const gchar *time2string (time_t t, const gchar *date_format);
 
-void mime_exec_single (GnomeCmdFile *f);
-void mime_exec_multiple (GList *files, GnomeCmdApp *app);
-
 void clear_event_key (GdkEventKey *event);
 
 inline gboolean state_is_blank (gint state)
@@ -196,15 +191,10 @@ void set_cursor_busy_for_widget (GtkWidget *widget);
 
 inline void set_cursor_default_for_widget (GtkWidget *widget)
 {
-#if GTK_CHECK_VERSION (2, 14, 0)
     GdkWindow *window = gtk_widget_get_window (widget);
 
     if (window)
         gdk_window_set_cursor (window, NULL);
-#else
-    if (widget->window)
-        gdk_window_set_cursor (widget->window, NULL);
-#endif
 }
 
 void set_cursor_busy ();
@@ -277,15 +267,7 @@ inline void gnome_cmd_show_message (GtkWindow *parent, std::string message, cons
 }
 
 
-inline void gnome_cmd_help_display (const gchar *file_name, const gchar *link_id=NULL)
-{
-    GError *error = NULL;
-
-    gnome_help_display (file_name, link_id, &error);
-
-    if (error != NULL)
-        gnome_cmd_error_message (_("There was an error displaying help."), error);
-}
+void gnome_cmd_help_display (const gchar *file_name, const gchar *link_id=NULL);
 
 
 inline void gnome_cmd_error_message (const gchar *title, GError *error)
@@ -322,7 +304,7 @@ inline std::string &stringify(std::string &s, gchar *val)
 }
 
 template <typename T>
-inline std::string &stringify(std::string &s, const T &val)
+std::string &stringify(std::string &s, const T &val)
 {
    std::ostringstream os;
 
@@ -350,7 +332,7 @@ inline std::string stringify(const T &val)
 int split(const std::string &s, std::vector<std::string> &coll, const char *sep);
 
 template <typename Iterator>
-inline std::ostream &join(std::ostream &os, Iterator beg, Iterator end, const std::string sep=" ")
+inline std::ostream &join(std::ostream &os, Iterator beg, Iterator end, const std::string &sep=" ")
 {
     if (beg==end)  return os;
 
@@ -369,13 +351,13 @@ inline std::ostream &join(std::ostream &os, Iterator beg, Iterator end, const st
 // }
 
 template <typename T, typename Compare, typename Allocator, template <typename, typename, typename> class COLL>
-inline std::ostream &join(std::ostream &os, const COLL<T, Compare, Allocator> &coll, const std::string sep=" ")
+inline std::ostream &join(std::ostream &os, const COLL<T, Compare, Allocator> &coll, const std::string &sep=" ")
 {
     return join(os,coll.begin(),coll.end(),sep);
 }
 
 template <typename Iterator>
-inline std::string &join(std::string &s, Iterator beg, Iterator end, const std::string sep=" ")
+inline std::string &join(std::string &s, Iterator beg, Iterator end, const std::string &sep=" ")
 {
     s.clear();
 
@@ -400,13 +382,13 @@ inline std::string &join(std::string &s, Iterator beg, Iterator end, const std::
 // }
 
 template <typename T, typename Compare, typename Allocator, template <typename, typename, typename> class COLL>
-inline std::string &join(std::string &s, const COLL<T, Compare, Allocator> &coll, const std::string sep=" ")
+inline std::string &join(std::string &s, const COLL<T, Compare, Allocator> &coll, const std::string &sep=" ")
 {
     return join(s,coll.begin(),coll.end(),sep);
 }
 
 template <typename Iterator>
-inline std::string join(Iterator beg, Iterator end, const std::string sep=" ")
+inline std::string join(Iterator beg, Iterator end, const std::string &sep=" ")
 {
     std::string s;
 
@@ -422,7 +404,7 @@ inline std::string join(Iterator beg, Iterator end, const std::string sep=" ")
 // }
 
 template <typename T, typename Compare, typename Allocator, template <typename, typename, typename> class COLL>
-inline std::string join(const COLL<T, Compare, Allocator> &coll, const std::string sep=" ")
+inline std::string join(const COLL<T, Compare, Allocator> &coll, const std::string &sep=" ")
 {
     std::string s;
 
@@ -430,5 +412,3 @@ inline std::string join(const COLL<T, Compare, Allocator> &coll, const std::stri
 }
 
 gint get_string_pixel_size (const char *s, int len);
-
-#endif // __UTILS_H__
