@@ -2,7 +2,7 @@
  * @file widget-factory.h
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2016 Uwe Scholz\n
+ * @copyright (C) 2013-2017 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,8 +19,7 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-#ifndef __WIDGET_FACTORY_H__
-#define __WIDGET_FACTORY_H__
+#pragma once
 
 #include "libgcmd/libgcmd-deps.h"
 #include "gnome-cmd-combo.h"
@@ -34,5 +33,3 @@ inline GnomeCmdCombo *create_clist_combo (GtkWidget *parent, gint num_cols, gint
 
     return combo;
 }
-
-#endif // __WIDGET_FACTORY_H__
