@@ -4,7 +4,7 @@
  *
  * @copyright (C) 2006 Assaf Gordon\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2016 Uwe Scholz\n
+ * @copyright (C) 2013-2017 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,11 +22,9 @@
  */
 
  #include "gtest/gtest.h"
- #include <glib-object.h>
+
 
 int main(int argc, char **argv) {
-  if (glib_check_version (2, 36, 0) != NULL)
-    g_type_init ();
   ::testing::InitGoogleTest(&argc, argv);
   return RUN_ALL_TESTS();
 }
